@@ -28,13 +28,24 @@ config = GetConfig.getConfig()
 a = shasta.Assembler()
 a.accessMarkers()
 
+# This can fail if sorted markers are not avaialble, in which 
+# case alignOrientedReads4 computes sorted markers on the fly.
+a.accessSortedMarkers()
+
 # Compute the alignment.
 a.alignOrientedReads4(
     readId0 = arguments.readId0, strand0 = arguments.strand0,
     readId1 = arguments.readId1, strand1 = arguments.strand1,
-    m = 2,
-    deltaX = 100,
-    deltaY = 20,
+    deltaX = int(config['Align']['align4.deltaX']),
+    deltaY = int(config['Align']['align4.deltaY']),
+    minEntryCountPerCell = int(config['Align']['align4.minEntryCountPerCell']),
+    maxDistanceFromBoundary = int(config['Align']['align4.maxDistanceFromBoundary']),
+    minAlignedMarkerCount = int(config['Align']['minAlignedMarkerCount']),
+    minAlignedFraction = float(config['Align']['minAlignedFraction']),
+    maxSkip = int(config['Align']['maxSkip']),
+    maxDrift = int(config['Align']['maxDrift']),
+    maxTrim = int(config['Align']['maxTrim']),
+    maxBand = int(config['Align']['maxBand']),
     matchScore = int(config['Align']['matchScore']),
     mismatchScore = int(config['Align']['mismatchScore']),
     gapScore = int(config['Align']['gapScore']))
