@@ -29,8 +29,6 @@ if not (os.path.isdir('conf') and os.path.isdir('src')):
 configurations = [
     'Nanopore-Dec2019',
     'Nanopore-UL-Dec2019',
-    'Nanopore-Jun2020',
-    'Nanopore-UL-Jun2020',
     'Nanopore-Sep2020',
     'Nanopore-UL-Sep2020',
     'Nanopore-UL-iterative-Sep2020',
@@ -48,6 +46,11 @@ configurations = [
     'Nanopore-UL-Phased-May2022',
     'Nanopore-Human-SingleFlowcell-May2022',
     'Nanopore-Human-SingleFlowcell-Phased-May2022',
+    'Nanopore-UL-Phased-Nov2022',
+    'Nanopore-R10-Fast-Nov2022',
+    'Nanopore-R10-Slow-Nov2022',
+    'Nanopore-Phased-R10-Fast-Nov2022',
+    'Nanopore-Phased-R10-Slow-Nov2022',
     ]
 
 
