@@ -10,7 +10,7 @@ config = GetConfig.getConfig()
 # Initialize the assembler and access what we need.
 a = shasta.Assembler()
 a.accessMarkers()
-a.accessAlignmentData()
+a.accessAlignmentDataReadWrite()
 
 # Create the global read graph.
 a.createReadGraph(
