@@ -2,11 +2,11 @@
 #define SHASTA_ASSEMBLER_HPP
 
 // Shasta.
+#include "Alignment.hpp"
 #include "AlignmentCandidates.hpp"
 #include "AssemblyGraph2Statistics.hpp"
 #include "HttpServer.hpp"
 #include "Kmer.hpp"
-#include "LocalAlignmentCandidateGraph.hpp"
 #include "Marker.hpp"
 #include "MarkerGraph.hpp"
 #include "MemoryMappedObject.hpp"
@@ -27,6 +27,7 @@ namespace shasta {
     class AssemblerInfo;
     class AssemblyGraph;
     class Alignment;
+    class AlignmentData;
     class AlignmentGraph;
     class AlignmentInfo;
     class AlignOptions;
@@ -72,6 +73,8 @@ namespace shasta {
     namespace mode3 {
         class AssemblyGraph;
     }
+
+    extern template class MultithreadedObject<Assembler>;
 }
 
 namespace spoa {
@@ -168,10 +171,13 @@ public:
     // Mode 2 assembly statistics.
     AssemblyGraph2Statistics assemblyGraph2Statistics;
 
-    // Performance statistics.
+    // Performance information.
     double assemblyElapsedTimeSeconds = 0.;
     double averageCpuUtilization;
     uint64_t peakMemoryUsage = 0ULL;
+    uint64_t threadCount = 0;
+    uint64_t virtualCpuCount = 0;
+    uint64_t totalAvailableMemory = 0;
 
     inline string peakMemoryUsageForSummaryStats() {
         return peakMemoryUsage > 0 ? to_string(peakMemoryUsage) : "Not determined.";
@@ -182,10 +188,7 @@ public:
 
 class shasta::Assembler :
     public MultithreadedObject<Assembler>
-#ifdef SHASTA_HTTP_SERVER
-    , public HttpServer
-#endif
-    {
+    , public HttpServer {
 public:
 
 
@@ -221,7 +224,7 @@ public:
     // Create a histogram of read lengths.
     void histogramReadLength(const string& fileName);
 
- 
+
     // Functions related to markers.
     // See the beginning of Marker.hpp for more information.
     void findMarkers(size_t threadCount);
@@ -309,7 +312,7 @@ public:
     // Find the vertex of the global marker graph that contains a given marker.
     // The marker is specified by the ReadId and Strand of the oriented read
     // it belongs to, plus the ordinal of the marker in the oriented read.
-    MarkerGraph::VertexId getGlobalMarkerGraphVertex(
+    MarkerGraphVertexId getGlobalMarkerGraphVertex(
         ReadId,
         Strand,
         uint32_t ordinal) const;
@@ -938,7 +941,7 @@ private:
     // The order in compressedAlignments matches that in alignmentData.
     MemoryMapped::Vector<AlignmentData> alignmentData;
     MemoryMapped::VectorOfVectors<char, uint64_t> compressedAlignments;
-    
+
     void checkAlignmentDataAreOpen() const;
 public:
     void accessCompressedAlignments();
@@ -1302,9 +1305,9 @@ private:
     // The next VertexId can be invalidVertexId if the oriented read has no vertices
     // past the starting VertexId.
     void findNextMarkerGraphVertices(
-        MarkerGraph::VertexId,
+        MarkerGraphVertexId,
         uint32_t maxSkip,
-        vector<MarkerGraph::VertexId>&) const;
+        vector<MarkerGraphVertexId>&) const;
 
 
 
@@ -1577,16 +1580,16 @@ private:
         vector< pair<OrientedReadId, uint32_t> >&) const;
 
     void getGlobalMarkerGraphVertexChildren(
-        MarkerGraph::VertexId,
-        vector< pair<MarkerGraph::VertexId, vector<MarkerInterval> > >&,
-        vector< pair<MarkerGraph::VertexId, MarkerInterval> >& workArea
+        MarkerGraphVertexId,
+        vector< pair<MarkerGraphVertexId, vector<MarkerInterval> > >&,
+        vector< pair<MarkerGraphVertexId, MarkerInterval> >& workArea
         ) const;
 
     // Given two marker graph vertices, get the marker intervals
     // that a possible edge between the two vertices would have.
     void getMarkerIntervals(
-        MarkerGraph::VertexId,
-        MarkerGraph::VertexId,
+        MarkerGraphVertexId,
+        MarkerGraphVertexId,
         vector<MarkerInterval>&
         ) const;
 
@@ -1794,7 +1797,7 @@ private:
         MarkerGraphEdgeId,
         uint32_t markerGraphEdgeLengthThresholdForConsensus,
         const std::unique_ptr<spoa::AlignmentEngine>& spoaAlignmentEngine,
-        const std::unique_ptr<spoa::Graph>& spoaAlignmentGraph,
+        spoa::Graph& spoaAlignmentGraph,
         vector<Base>& sequence,
         vector<uint32_t>& repeatCounts,
         uint8_t& overlappingBaseCount,
@@ -2165,8 +2168,6 @@ public:
     static void writeStyle(ostream& html);
 
 
-#ifdef SHASTA_HTTP_SERVER
-
     void writeNavigation(ostream&) const;
     void writeNavigation(
         ostream& html,
@@ -2209,7 +2210,7 @@ public:
     static void addScaleSvgButtons(ostream&, uint64_t sizePixels);
     class HttpServerData {
     public:
-        LocalAlignmentCandidateGraph referenceOverlapGraph;
+        shared_ptr<LocalAlignmentCandidateGraph> referenceOverlapGraph;
 
         using ServerFunction = void (Assembler::*) (
             const vector<string>& request,
@@ -2278,7 +2279,6 @@ public:
     );
     void writeColorPicker(ostream& html, string svgId);
 
-#endif
     void writeMakeAllTablesCopyable(ostream&) const;
 
     // Do bulk sampling of reads and accumulate stats about their alignments
@@ -2379,6 +2379,9 @@ private:
     void exploreMode3AssemblyGraphSegment(const vector<string>&, ostream&);
     void exploreMode3AssemblyGraphSegmentPair(const vector<string>&, ostream&);
     void exploreMode3AssemblyGraphLink(const vector<string>&, ostream&);
+    void exploreMode3MetaAlignment(const vector<string>&, ostream&);
+    void exploreMode3AssemblyPath(const vector<string>&, ostream&);
+    void exploreMode3LinkAssembly(const vector<string>&, ostream&);
 
 
 
@@ -2418,6 +2421,8 @@ public:
     shared_ptr<mode3::AssemblyGraph> assemblyGraph3Pointer;
     void accessMode3AssemblyGraph();
     void analyzeMode3Subgraph(const vector<uint64_t>& segmentIds);
+    void createMode3PathGraph();
+    void createMode3Detangler();
 
 
 
