@@ -16,15 +16,14 @@ using namespace shasta;
 
 // Standard library.
 #include "chrono.hpp"
+#include <filesystem>
 #include "iterator.hpp"
 #include <numeric>
 #include <queue>
 #include <unordered_map>
 
 // This is needed for mallopt.
-#ifdef __linux__
 #include <malloc.h>
-#endif
 
 
 
@@ -675,13 +674,11 @@ void Assembler::assemble(
 
     // Create the Coverage directory, if necessary.
     if(assembleData.storeCoverageDataCsvLengthThreshold > 0) {
-        filesystem::createDirectory("Coverage");
+        SHASTA_ASSERT(std::filesystem::create_directory("Coverage"));
     }
 
     // Attempt to reduce memory fragmentation.
-#ifdef __linux__
     mallopt(M_MMAP_THRESHOLD, 16*1024);
-#endif
 
     // Do all the assemblies.
     cout << "Assembly begins for " << assemblyGraph.edgeLists.size() <<
@@ -1169,7 +1166,7 @@ void Assembler::writeGfa1BothStrands(const string& fileName)
         gfa << "\n";
     }
 
-  
+
     // Write GFA links.
     // For each vertex in the assembly graph there is a link for
     // each combination of in-edges and out-edges.
@@ -1776,7 +1773,7 @@ void Assembler::assembleAssemblyGraphEdge(
     AssembledSegment& assembledSegment)
 {
     AssemblyGraph& assemblyGraph = *assemblyGraphPointer;
-    const span<const MarkerGraph::EdgeId> markerGraphPath = makeSpanOfConst(assemblyGraph.edgeLists[edgeId]);
+    const span<const MarkerGraph::EdgeId> markerGraphPath = assemblyGraph.edgeLists[edgeId];
     assembleAssemblyGraphEdge(markerGraphPath, storeCoverageData, assembledSegment);
 }
 
