@@ -1,5 +1,3 @@
-#ifdef SHASTA_HTTP_SERVER
-
 // Shasta.
 #include "Assembler.hpp"
 #include "AssembledSegment.hpp"
@@ -16,6 +14,8 @@ using namespace shasta;
 
 // Standard library.
 #include "chrono.hpp"
+#include <filesystem>
+#include "fstream.hpp"
 
 
 
@@ -91,11 +91,11 @@ void Assembler::exploreAssemblyGraph(
         const int exitStatus = WEXITSTATUS(commandStatus);
         if(exitStatus == 124) {
             html << "<p>Timeout for graph layout exceeded. Increase the timeout or reduce the maximum distance from the start vertex.";
-            filesystem::remove(dotFileName);
+            std::filesystem::remove(dotFileName);
             return;
         }
         else if(exitStatus!=0 && exitStatus!=1) {    // sfdp returns 1 all the time just because of the message about missing triangulation.
-            filesystem::remove(dotFileName);
+            std::filesystem::remove(dotFileName);
             throw runtime_error("Error " + to_string(exitStatus) + " running graph layout command: " + command);
         }
     } else if(WIFSIGNALED(commandStatus)) {
@@ -107,7 +107,7 @@ void Assembler::exploreAssemblyGraph(
     }
 
     // Remove the .dot file.
-    filesystem::remove(dotFileName);
+    std::filesystem::remove(dotFileName);
 
     // Buttons to resize the svg locally.
     html << "<br>";
@@ -121,7 +121,7 @@ void Assembler::exploreAssemblyGraph(
     svgFile.close();
 
     // Remove the .svg file.
-    filesystem::remove(svgFileName);
+    std::filesystem::remove(svgFileName);
 
     // Scale to desired size, then make it visible.
     html <<
@@ -428,13 +428,7 @@ void Assembler::exploreAssemblyGraphEdgesSupport(
         }
 
         // Extract the edge id.
-        AssemblyGraph::EdgeId edgeId;
-        try {
-            edgeId = boost::lexical_cast<AssemblyGraph::EdgeId>(edgeString);
-        } catch(const boost::bad_lexical_cast&) {
-            html << "<br>Invalid assembly graph edge id " << token;
-            return;
-        }
+        const AssemblyGraph::EdgeId edgeId = std::stoul(edgeString);
 
         // Check that it is a valid assembly graph edge id.
         if(edgeId >= assemblyGraph.edges.size()) {
@@ -626,7 +620,3 @@ void Assembler::exploreAssemblyGraphEdgesSupport(
     html << "</table>";
 
 }
-
-
-
-#endif
