@@ -1,10 +1,9 @@
-#ifdef SHASTA_HTTP_SERVER
-
 // Shasta.
 #include "Assembler.hpp"
 #include "CompressedAssemblyGraph.hpp"
 #include "platformDependent.hpp"
 #include "runCommandWithTimeout.hpp"
+#include "timestamp.hpp"
 using namespace shasta;
 
 // Boost libraries.
@@ -14,8 +13,12 @@ using namespace shasta;
 #include <boost/uuid/uuid_io.hpp>
 
 // Standard library.
+#include <filesystem>
+#include "fstream.hpp"
 #include <map>
 
+
+
 void Assembler::exploreCompressedAssemblyGraph(
     const vector<string>& request,
     ostream& html)
@@ -192,7 +195,7 @@ void Assembler::exploreCompressedAssemblyGraph(
             ". The failing Command was: <code>" << command << "</code>";
         return;
     }
-    filesystem::remove(dotFileName);
+    std::filesystem::remove(dotFileName);
 
 
     // Display the graph.
@@ -200,8 +203,6 @@ void Assembler::exploreCompressedAssemblyGraph(
     ifstream svgFile(svgFileName);
     html << svgFile.rdbuf();
     svgFile.close();
-    filesystem::remove(svgFileName);
+    std::filesystem::remove(svgFileName);
 
 }
-
-#endif
\ No newline at end of file
