@@ -1,5 +1,3 @@
-#ifdef SHASTA_HTTP_SERVER
-
 // Shasta.
 #include "Assembler.hpp"
 #include "deduplicate.hpp"
@@ -48,8 +46,8 @@ void Assembler::exploreReadRle(
     std::set<uint32_t> highlightedMarkers;
     for(const string& s: highlightedMarkerStrings) {
         try {
-            highlightedMarkers.insert(boost::lexical_cast<uint32_t>(s));
-        } catch(std::exception&) {
+            highlightedMarkers.insert(uint32_t(std::stoi(s)));
+        } catch (...) {
             // Ignore.
         }
     }
@@ -78,7 +76,7 @@ void Assembler::exploreReadRle(
         (requestReadName.empty() ? "" : " value='" + requestReadName + "'") <<
         "> on strand ";
     writeStrandSelection(html, "strand", strandIsPresent && strand==0, strandIsPresent && strand==1);
-    
+
     html << "<font color=grey style='font-size:smaller'>";
     html << "&nbsp&nbsp starting at&nbsp";
     html << "<input type=text name=beginPosition size=8 "
@@ -87,7 +85,7 @@ void Assembler::exploreReadRle(
         html << " value=" << beginPosition;
     }
     html << "> &nbsp ending at&nbsp";
-    
+
     html << "<input type=text name=endPosition size=8 "
         "title='End display of raw sequence at this base position (leave blank to end at end of read).'";
     if(endPositionIsPresent) {
@@ -101,7 +99,7 @@ void Assembler::exploreReadRle(
     }
     html << "> highlighted.";
     html << "</font>";
-    
+
 
 
     // Checkboxes to choose what we want to display.
@@ -265,7 +263,7 @@ void Assembler::exploreReadRle(
 
         // Link to align this read against another read.
         html <<
-            "<button style='background-color:lightsteelblue;font-size:12px;margin-top:16px' " 
+            "<button style='background-color:lightsteelblue;font-size:12px;margin-top:16px' "
             "onclick=\"window.location.href = 'exploreAlignment?readId0=" << readId << "&strand0=" << strand <<
             "';\">Compute a marker alignment of this read with another read</button>";
 
@@ -273,7 +271,7 @@ void Assembler::exploreReadRle(
 
         // Link to show overlapping reads.
         html <<
-            "<button style='background-color:lightsteelblue;font-size:12px;margin-top:4px' " 
+            "<button style='background-color:lightsteelblue;font-size:12px;margin-top:4px' "
             "onclick=\"window.location.href = 'exploreAlignments?readId=" << readId << "&strand=" << strand <<
             "';\">Find other reads that overlap this read</button>";
 
@@ -609,7 +607,7 @@ void Assembler::exploreReadRle(
             html << "</text>";
         }
 
-        
+
         // Read sequence in run length encoding.
         // This code uses one <text> element for every blockSize characters.
         // This way you can select sequence text without getting a
@@ -631,7 +629,7 @@ void Assembler::exploreReadRle(
             }
             html << "</text>";
         }
-    
+
 
 
         // Draw a rectangle for each highlighted marker.
@@ -817,7 +815,7 @@ void Assembler::exploreReadRle(
         for(uint32_t i=0; i<kmers.size(); i++) {
             markerFrequencyTable.push_back(make_pair(kmers[i], kmerFrequency[i]));
         }
-        sort(markerFrequencyTable.begin(), markerFrequencyTable.end(),
+        std::ranges::sort(markerFrequencyTable,
             OrderPairsBySecondOnlyGreater<KmerId, uint32_t>());
 
         if(beginPositionIsPresent || endPositionIsPresent) {
@@ -950,6 +948,7 @@ void Assembler::exploreReadRaw(
     const auto sequence = reads->getRead(readId);
     const auto readName = reads->getReadName(readId);
     const auto metaData = reads->getReadMetaData(readId);
+    const span<const CompressedMarker> orientedReadMarkers = markers[orientedReadId.getValue()];
 
     // Adjust the position range, if necessary.
     if(!beginPositionIsPresent) {
@@ -996,13 +995,23 @@ void Assembler::exploreReadRaw(
     html << "</table>";
 
 
-
-    // Sequence.
-    html << "<p><pre style='font-family:monospace;margin:0'>";
-    for(uint64_t position=beginPosition; position!=endPosition; position++) {
-        html << sequence[position];
+    // Position scale labels.
+    html << "<p>For precise alignment of the following section, use Firefox to display this page.\n";
+    html << "<div style='font-family:Courier New;font-size:10pt;margin:0'>";
+    for(size_t position=beginPosition; position<endPosition; ) {
+        if((position%10)==0) {
+            const string label = to_string(position);
+            html << label;
+            for(size_t i=0; i<10-label.size(); i++) {
+                html << "&nbsp;";
+            }
+            position += 10;
+        } else {
+            html << "&nbsp;";
+            ++position;
+        }
     }
-    html<< "\n";
+    html<< "<br>";
 
     // Position scale
     for(size_t position=beginPosition; position<endPosition; position++) {
@@ -1014,26 +1023,113 @@ void Assembler::exploreReadRaw(
             html << ".";
         }
     }
-    html<< "\n";
+    html<< "<br>";
 
-    // Position scale labels.
-    for(size_t position=beginPosition; position<endPosition; ) {
-        if((position%10)==0) {
-            const string label = to_string(position);
-            html << label;
-            for(size_t i=0; i<10-label.size(); i++) {
-                html << " ";
+    // Sequence.
+    for(uint64_t position=beginPosition; position!=endPosition; position++) {
+        html << sequence[position];
+    }
+    html<< "<br>";
+
+
+
+    // Display the markers.
+
+    // If here are no markers, there is nothing to do.
+    if(orientedReadMarkers.empty()) {
+        html << "</div><p>This read has no markers.";
+        return;
+    }
+
+    // Because markers can overlap, we have to display them on more than one row.
+    // This vector will contain, for each row, the list of marker ordinals
+    // to be displayed in this row.
+    vector< vector<uint64_t> > markersByRow;
+
+    const uint64_t k = assemblerInfo->k;
+    for(uint64_t ordinal=0; ordinal<orientedReadMarkers.size(); ordinal++) {
+        const uint64_t position = orientedReadMarkers[ordinal].position;
+
+        // If this marker begins before our beginPosition, it will not be displayed.
+        if(position < beginPosition) {
+            continue;
+        }
+
+        // If this marker ends after our endPosition, it will not be displayed.
+        if(position + k > endPosition) {
+            continue;
+        }
+
+        // Try all rows.
+        for(uint64_t row=0; ; row++) {
+            if(row >= markersByRow.size()) {
+                markersByRow.resize(row + 1);
+            }
+            vector<uint64_t>& markersOnThisRow = markersByRow[row];
+            if(markersOnThisRow.empty() or position > orientedReadMarkers[markersOnThisRow.back()].position + k) {
+                markersOnThisRow.push_back(ordinal);
+                break;
             }
-            position += 10;
-        } else {
-            html << " ";
-            ++position;
         }
     }
-    html<< "\n";
-    html << "</pre>";
+
+    // Display the markers on each row.
+    for(const vector<uint64_t>&markersOnThisRow: markersByRow) {
+
+        // Loop over the markers on this row.
+        uint64_t oldPosition = 0;
+        for(const uint64_t ordinal: markersOnThisRow) {
+            const CompressedMarker& marker = orientedReadMarkers[ordinal];
+            const uint64_t position = marker.position - beginPosition;
+            const Kmer kmer(marker.kmerId, k);
+
+            // Write the required number of spaces.
+            SHASTA_ASSERT(position > oldPosition);  // There must be at least a blank.
+            for(uint64_t i=oldPosition; i<position; i++) {
+                html << "&nbsp;";
+            }
+            oldPosition = position + k;
+
+            // See if this marker is contained in a vertex of the marker graph.
+            const MarkerGraph::VertexId vertexId =
+                getGlobalMarkerGraphVertex(orientedReadId, uint32_t(ordinal));
+            const bool hasMarkerGraphVertex =
+                (vertexId != MarkerGraph::invalidCompressedVertexId);
+
+            if(hasMarkerGraphVertex) {
+
+                // There is a marker graph vertex.
+                // Write the marker as a link to that vertex.
+                const string url = "exploreMarkerGraph?vertexId=" + to_string(vertexId) +
+                    "&maxDistance=6&detailed=on&sizePixels=600&timeout=30";
+                html << "<a href='" << url << "' title='Marker " << ordinal <<
+                    ", position " << marker.position <<
+                    ", coverage " << markerGraph.vertexCoverage(vertexId) <<
+                    "'>";
+
+                // Write the k-mer.
+                for(uint64_t i=0; i<k; i++) {
+                    html << kmer[i];
+                }
+                html << "</a>";
+
+            } else {
+
+                // There is no marker graph vertex.
+                // Write this marker as text.
+                html << "<span title='Marker " << ordinal <<
+                    ", position " << marker.position <<
+                    "'>";
+                for(uint64_t i=0; i<k; i++) {
+                    html << kmer[i];
+                }
+                html << "</span>";
+            }
+        }
+        html << "<br>";
+    }
+
+    html << "</div>";
 
 }
 
-
-#endif
