@@ -2,20 +2,22 @@
 // Shasta.
 #include "Assembler.hpp"
 #include "AssemblyGraph.hpp"
+#include "filesystem.hpp"
 #include "Coverage.hpp"
 #include "buildId.hpp"
-#include "filesystem.hpp"
 #include "platformDependent.hpp"
 #include "Reads.hpp"
 using namespace shasta;
 
 // Boost libraries.
+#include <boost/tokenizer.hpp>
 #include <boost/uuid/uuid.hpp>
 #include <boost/uuid/uuid_generators.hpp>
 #include <boost/uuid/uuid_io.hpp>
 
 // Standard library.
 #include <filesystem>
+#include "fstream.hpp"
 
 
 // A map containing descriptions of output files.
@@ -203,7 +205,6 @@ namespace shasta {
 
 
 
-#ifdef SHASTA_HTTP_SERVER
 
 #define SHASTA_ADD_TO_FUNCTION_TABLE(name) httpServerData.functionTable[string("/") + #name ] = &Assembler::name
 
@@ -244,6 +245,9 @@ void Assembler::fillServerFunctionTable()
     SHASTA_ADD_TO_FUNCTION_TABLE(exploreMode3AssemblyGraphSegment);
     SHASTA_ADD_TO_FUNCTION_TABLE(exploreMode3AssemblyGraphSegmentPair);
     SHASTA_ADD_TO_FUNCTION_TABLE(exploreMode3AssemblyGraphLink);
+    SHASTA_ADD_TO_FUNCTION_TABLE(exploreMode3MetaAlignment);
+    SHASTA_ADD_TO_FUNCTION_TABLE(exploreMode3AssemblyPath);
+    SHASTA_ADD_TO_FUNCTION_TABLE(exploreMode3LinkAssembly);
 
 }
 #undef SHASTA_ADD_TO_FUNCTION_TABLE
@@ -257,7 +261,7 @@ void Assembler::processRequest(
 {
     // Process a documentation request.
     const string& keyword = request.front();
-    
+
     if(keyword.size()>6 && keyword.substr(0, 6)=="/docs/") {
 
         // Extract the file name.
@@ -313,7 +317,6 @@ void Assembler::processRequest(
     }
     writeHtmlEnd(html);
 }
-#endif
 
 
 
@@ -415,9 +418,6 @@ function makeAllTablesSelectableByDoubleClick()
 
 
 
-#ifdef SHASTA_HTTP_SERVER
-
-
 void Assembler::writeNavigation(ostream& html) const
 {
     html << "<ul class=navigationMenu>";
@@ -465,9 +465,11 @@ void Assembler::writeNavigation(ostream& html) const
             {"Assembly graph segments", "exploreMode3AssemblyGraphSegment"},
             {"Assembly graph segment pairs", "exploreMode3AssemblyGraphSegmentPair"},
             {"Assembly graph links", "exploreMode3AssemblyGraphLink"},
+            {"Meta-alignments", "exploreMode3MetaAlignment"},
+            {"Assembly paths", "exploreMode3AssemblyPath"},
             });
     }
-    
+
     if (!httpServerData.docsDirectory.empty()) {
         writeNavigation(html, "Help", {
             {"Documentation", "docs/index.html"},
@@ -528,7 +530,7 @@ void Assembler::writePngToHtml(
     html << "\"/>";
 
     // Remove the base64 file.
-    filesystem::remove(base64FileName);
+    std::filesystem::remove(base64FileName);
 
 }
 
@@ -575,7 +577,6 @@ void Assembler::exploreSummary(
     writeAssemblySummaryBody(html);
 }
 
-#endif
 
 
 // Access all available assembly data, without throwing exceptions
@@ -783,6 +784,14 @@ void Assembler::writeStyle(ostream& html)
     a {
         color: DarkSlateBlue;
     }
+
+    /* This can be used to get vertical text in table cells. */
+    span.rotated 
+    {
+      writing-mode: vertical-rl;
+      transform: rotate(180deg);
+    }
+
     ul.navigationMenu {
         list-style-type: none;
         margin: 0px 0px 12px 0px;
@@ -790,7 +799,7 @@ void Assembler::writeStyle(ostream& html)
         overflow: hidden;
         background-color: #404040;
     }
-    
+
     div.navigationButton {
         display: inline-block;
         color: white;
@@ -799,7 +808,7 @@ void Assembler::writeStyle(ostream& html)
         text-decoration: none;
         // min-width: 120px;
     }
-    
+
     .navigationMenuEntry:hover .navigationButton {
         background-color: black;
     }
@@ -1211,9 +1220,15 @@ void Assembler::writeAssemblySummaryBody(ostream& html)
         "<td class=right>" << assemblerInfo->assemblyElapsedTimeSeconds/3600. <<
         "<tr><td>Average CPU utilization"
         "<td class=right>" << assemblerInfo->averageCpuUtilization <<
-        "<tr><td>Peak Memory utilization (bytes)"
+        "<tr><td>Peak virtual memory utilization (bytes)"
         "<td class=right>" <<
         assemblerInfo->peakMemoryUsageForSummaryStats() <<
+        "<tr><td>Number of threads used"
+        "<td class=right>" << assemblerInfo->threadCount <<
+        "<tr><td>Total number of virtual CPUs available"
+        "<td class=right>" << assemblerInfo->virtualCpuCount <<
+        "<tr><td>Total physical memory available (bytes)"
+        "<td class=right>" << assemblerInfo->totalAvailableMemory <<
         "</table>"
         ;
 }
@@ -1506,9 +1521,11 @@ void Assembler::writeAssemblySummaryJson(ostream& json)
         "    \"Elapsed time (minutes)\": " << assemblerInfo->assemblyElapsedTimeSeconds/60. << ",\n"
         "    \"Elapsed time (hours)\": " << assemblerInfo->assemblyElapsedTimeSeconds/3600. << ",\n"
         "    \"Average CPU utilization\": " << assemblerInfo->averageCpuUtilization << ",\n"
-        "    \"Peak Memory utilization (bytes)\": " <<
-        assemblerInfo->peakMemoryUsageForSummaryStats() <<
-        "\n"
+        "    \"Peak memory utilization (bytes)\": " <<
+        assemblerInfo->peakMemoryUsageForSummaryStats() << ",\n"
+        "    \"Number of threads used\": " << assemblerInfo->threadCount << ",\n"
+        "    \"Total number of virtual CPUs available\": " << assemblerInfo->virtualCpuCount << ",\n"
+        "    \"Total physical memory available (bytes)\": " << assemblerInfo->totalAvailableMemory << "\n"
         "  }\n"
 
 
@@ -1526,7 +1543,7 @@ void Assembler::writeAssemblyIndex(ostream& html) const
     // Loop over files in the assembly directory,
     // in case-insensitive alphabetic order.
     vector<string> assemblyFiles = shasta::filesystem::directoryContents(".");
-    sort(assemblyFiles.begin(), assemblyFiles.end(),
+    std::ranges::sort(assemblyFiles,
         [](const string& s1, const string& s2) {
         return lexicographical_compare(
         s1.begin(), s1.end(),
@@ -1557,9 +1574,6 @@ void Assembler::writeAssemblyIndex(ostream& html) const
 
 
 
-#ifdef SHASTA_HTTP_SERVER
-
-
 void Assembler::blastRead(
     const vector<string>& request,
     ostream& html)
@@ -1703,7 +1717,7 @@ void Assembler::blastRead(
         }
 
         // Sort by score.
-        sort(alignments.begin(), alignments.end(),
+        std::ranges::sort(alignments,
             std::greater< pair<double, vector<string> > >());
 
         // Write it out.
@@ -1769,9 +1783,9 @@ void Assembler::blastRead(
 
 
     // Remove the files we created.
-    filesystem::remove(fastaFileName);
-    filesystem::remove(blastOutputFileName);
-    filesystem::remove(blastErrFileName);
+    std::filesystem::remove(fastaFileName);
+    std::filesystem::remove(blastOutputFileName);
+    std::filesystem::remove(blastErrFileName);
 }
 
 
@@ -1797,5 +1811,3 @@ void shasta::writeStrandSelection(
         "</select>";
 
 }
-
-#endif
