@@ -1,8 +1,13 @@
+// Shasta.
 #include "Assembler.hpp"
 #include "deduplicate.hpp"
+#include "MurmurHash2.hpp"
 #include "Reads.hpp"
+#include "timestamp.hpp"
 using namespace shasta;
 
+// Standard library.
+#include "fstream.hpp"
 #include <random>
 
 
