@@ -1,5 +1,4 @@
 #include "AssemblyGraph.hpp"
-#include "BubbleGraph.hpp"
 #include "deduplicate.hpp"
 using namespace shasta;
 
@@ -64,10 +63,6 @@ void AssemblyGraph::close()
         edgeLists.close();
     }
 
-    if(bubbles.isOpen) {
-        bubbles.close();
-    }
-
     if(markerToAssemblyTable.isOpen()) {
         markerToAssemblyTable.close();
     }
@@ -117,10 +112,6 @@ void AssemblyGraph::remove()
         edgeLists.remove();
     }
 
-    if(bubbles.isOpen) {
-        bubbles.remove();
-    }
-
     if(markerToAssemblyTable.isOpen()) {
         markerToAssemblyTable.remove();
     }
@@ -352,99 +343,83 @@ void AssemblyGraph::findOutEdges(VertexId vertexId, vector<EdgeId>& edgeIds) con
 }
 
 
-// Find bubbles in the assembly graph.
-// A bubble is a set of two vertices v0, v1,
-// such that the outgoing edges of v0 are the same
-// as the outgoing edges of v1, and
-// out-degree(v0) = in-degree(v1) > 1.
-// v0 is called the bubble source.
-// v1 is called the bubble target.
-// In defining and detecting bubbles, edges
-// that were removed are considered to not exist.
-// This assumes that the bubble Vector was already initialized.
-void AssemblyGraph::findBubbles()
+
+// Write the AssemblyGraph to GFA without including sequence.
+// The sequence length of each edge is written as the number of
+// marker graph edges.
+// Equivalent functions including output of assembled sequence
+// are in class Assembler and should be moved here.
+// The GFA 1.0 format is described here:
+// https://github.com/GFA-spec/GFA-spec/blob/master/GFA1.md
+void AssemblyGraph::writeGfa1BothStrandsNoSequence(const string& fileName) const
+{
+    ofstream gfa(fileName);
+    writeGfa1BothStrandsNoSequence(gfa);
+}
+void AssemblyGraph::writeGfa1BothStrandsNoSequence(ostream& gfa) const
 {
-    // Define vectors here to reduce memory allocation overhead.
-    vector<EdgeId> v0OutEdges;
-    vector<EdgeId> v1InEdges;
 
-    // Histogram of number of bubbles by ploidy.
-    vector<EdgeId> histogram;
+    // Write the header line.
+    gfa << "H\tVN:Z:1.0\n";
 
-    // Loop over possible source vertices for a bubble.
-    bubbles.clear();
-    for(VertexId v0=0; v0<vertices.size(); v0++) {
+    // Write a segment record for each edge.
+    for(EdgeId edgeId=0; edgeId<edgeLists.size(); edgeId++) {
 
-        // Find the out-edges of v0.
-        findOutEdges(v0, v0OutEdges);
-
-        // If less than 2 out-edges, v0 is not a bubble source.
-        if(v0OutEdges.size() < 2) {
+        // If this edge was removed, skip it.
+        if(edges[edgeId].wasRemoved()) {
             continue;
         }
 
-        // Find the ossible bubble target.
-        const VertexId v1 = edges[v0OutEdges.front()].target;
+        // Record type.
+        gfa << "S\t";
 
-        // Check if all out-edges of v0 have the same target.
-        bool isBubble = true;
-        for(const EdgeId e: v0OutEdges) {
-            if(edges[e].target != v1) {
-                isBubble = false;
-                break;
+        // Name.
+        gfa << edgeId << "\t";
+
+        // Sequence.
+        gfa << "*\t";
+
+        // Sequence length is written out expressed in markers.
+        gfa << "LN:i:" << edgeLists.size(edgeId) << "\n";
+    }
+
+
+    // Write GFA links.
+    // For each vertex in the assembly graph there is a link for
+    // each combination of in-edges and out-edges.
+    // Therefore each assembly graph vertex generates a number of
+    // links equal to the product of its in-degree and out-degree.
+    for(VertexId vertexId=0; vertexId<vertices.size(); vertexId++) {
+
+        // In-edges.
+        const span<const EdgeId> edges0 = edgesByTarget[vertexId];
+
+        // Out-edges.
+        const span<const EdgeId> edges1 = edgesBySource[vertexId];
+
+        // Loop over in-edges.
+        for(const EdgeId edge0: edges0) {
+            if(edges[edge0].wasRemoved()) {
+                continue;
+            }
+
+            // Loop over out-edges.
+            for(const EdgeId edge1: edges1) {
+                if(edges[edge1].wasRemoved()) {
+                    continue;
+                }
+
+                // Write out the link record for this edge,
+                // with the CIGAR string left unspecified.
+                // Note all links are written with orientation ++.
+                gfa << "L\t" <<
+                    edge0 << "\t+\t" <<
+                    edge1 << "\t+\t*\n";
             }
         }
-        if(!isBubble) {
-            continue;
-        }
-
-        // Find the in-edges of v1.
-        findInEdges(v1, v1InEdges);
-
-        // For this to be a bubble, the in-edges of v1
-        // must be the same as the out-edges of v0.
-        if(v1InEdges != v0OutEdges) {
-            continue;
-        }
-
-        // Store this bubble.
-        bubbles.push_back(Bubble(v0, v1));
-
-        // Update the histogram by ploidy.
-        const uint64_t ploidy = v0OutEdges.size();
-        if(histogram.size() <= ploidy) {
-            histogram.resize(ploidy+1, 0);
-        }
-        ++histogram[ploidy];
-
     }
-    VertexId bubbleCount = 0;
-    VertexId bubbleEdgeCount = 0;
-    for(uint64_t ploidy=0; ploidy<histogram.size(); ploidy++) {
-        const uint64_t frequency = histogram[ploidy];
-        if(frequency) {
-            bubbleCount += frequency;
-            bubbleEdgeCount += frequency * ploidy;
-            cout << "Found " << frequency << " bubbles with ploidy " << ploidy << endl;
-        }
-    }
-    cout << "Total number of bubbles is " << bubbleCount << "." << endl;
-
-    // Edge statistics.
-    const AssemblyGraph::EdgeId totalEdgeCount = edgeCount();
-    cout << "Assembly graph edge statistics:" << endl;
-    cout << "Total number of edges is " << totalEdgeCount << "." << endl;
-    cout << "Total number of bubble edges is " << bubbleEdgeCount << "." << endl;
-    cout << "Total number of non-bubble edges is " << totalEdgeCount-bubbleEdgeCount << "." << endl;
-}
 
 
-
-void AssemblyGraph::findBubbleChains()
-{
-    BubbleGraph graph(*this);
-    graph.findLinearChains();
-    graph.writeLinearChains("BubbleChains.csv", *this);
 }
 
 
@@ -461,92 +436,3 @@ AssemblyGraph::EdgeId AssemblyGraph::edgeCount() const
     return count;
 }
 
-
-
-// Find and store the assembly graph forks.
-// The fork corresponding to a bubble is stored only once.
-// This function assumes that the assembly graph has no removed edges.
-void AssemblyGraph::createForks()
-{
-    // Simple-minded code to find forks.
-    vector<ForkInfo> forkInfos;
-    for(VertexId vertexId=0; vertexId<vertices.size(); vertexId++) {
-        const span<EdgeId> outgoingEdges = edgesBySource[vertexId];
-        if(outgoingEdges.size() > 1) {
-            ForkInfo forkInfo;
-            forkInfo.vertexId = vertexId;
-            forkInfo.isForward = true;
-            copy(outgoingEdges.begin(), outgoingEdges.end(), back_inserter(forkInfo.edgeIds));
-            forkInfos.push_back(forkInfo);
-        }
-        const span<EdgeId> incomingEdges = edgesByTarget[vertexId];
-        if(incomingEdges.size() > 1) {
-            ForkInfo forkInfo;
-            forkInfo.vertexId = vertexId;
-            forkInfo.isForward = false;
-            copy(incomingEdges.begin(), incomingEdges.end(), back_inserter(forkInfo.edgeIds));
-            forkInfos.push_back(forkInfo);
-        }
-    }
-
-    // Remove duplicates (the fork in a bubble is stored only once).
-    const uint64_t forkCountBeforeDeduplication = forkInfos.size();
-    deduplicate(forkInfos);
-
-    // Store.
-    forks.clear();
-    for(const Fork& fork: forkInfos) {
-        forks.push_back(fork);
-    }
-    const uint64_t forkCount = forks.size();
-    const uint64_t bubbleCount = forkCountBeforeDeduplication - forkCount;
-    cout << "Found " << forks.size() << " forks in the assembly graph, including " <<
-        bubbleCount <<
-        " bubbles." << endl;
-
-    // Compute the size distribution of forks.
-    vector<uint64_t> histogram;
-    for(const Fork& fork: forks) {
-        const uint64_t branchCount =
-            fork.isForward ?
-            edgesBySource.size(fork.vertexId) :
-            edgesByTarget.size(fork.vertexId);
-        if(branchCount >= histogram.size()) {
-            histogram.resize(branchCount+1, 0);
-        }
-        ++histogram[branchCount];
-    }
-    cout << "Size distribution of forks:" << endl;
-    for(uint64_t branchCount=0; branchCount<histogram.size(); branchCount++) {
-        const uint64_t frequency = histogram[branchCount];
-        if(frequency) {
-            cout << branchCount << " " << frequency << endl;
-        }
-    }
-
-    // Write details of each fork.
-    for(size_t iFork=0; iFork<forks.size(); iFork++) {
-        const Fork& fork = forks[iFork];
-        const auto edges =
-            fork.isForward ?
-            edgesBySource[fork.vertexId] :
-            edgesByTarget[fork.vertexId];
-        cout << "Fork " << iFork << ":";
-        for(const auto edge: edges) {
-            cout << " " << edge;
-        }
-        cout << endl;
-    }
-}
-
-
-
-span<AssemblyGraph::EdgeId> AssemblyGraph::getForkEdges(uint64_t forkId)
-{
-    const Fork& fork = forks[forkId];
-    if(fork.isForward) {
-        return edgesBySource[fork.vertexId];
-    } else {
-        return edgesByTarget[fork.vertexId];
-    }
-}
