@@ -19,6 +19,7 @@ vertex in the assembly graph.
 #include "LongBaseSequence.hpp"
 #include "MarkerGraph.hpp"
 #include "MemoryMappedVectorOfVectors.hpp"
+#include "shastaTypes.hpp"
 
 // Standard library.
 #include <limits>
@@ -34,8 +35,8 @@ public:
 
     // Use the same vertex and edge ids of the marker graph.
     // We could probably get away with 32 bits.
-    using VertexId = MarkerGraph::VertexId;
-    using EdgeId = MarkerGraph::EdgeId;
+    using VertexId = AssemblyGraphVertexId;
+    using EdgeId = AssemblyGraphEdgeId;
     static const VertexId invalidVertexId = std::numeric_limits<VertexId>::max();
     static const VertexId invalidEdgeId = std::numeric_limits<EdgeId>::max();
 
@@ -138,38 +139,6 @@ public:
 
 
 
-    // Bubbles in the assembly graph.
-    // A bubble is a set of two vertices v0, v1
-    // such that the outgoing edges of v0 are the same
-    // as the outgoing edges of v1, and
-    // out-degree(v0) = in-degree(v1) > 1.
-    // v0 is called the bubble source.
-    // v1 is called the bubble target.
-    // In defining and detecting bubbles, edges
-    // that were removed are considered to not exist.
-    class Bubble {
-    public:
-        VertexId v0;
-        VertexId v1;
-        Bubble() {}
-        Bubble(VertexId v0, VertexId v1) : v0(v0), v1(v1) {}
-    };
-    MemoryMapped::Vector<Bubble> bubbles;
-    void findBubbles(); // Assumes bubble was already initialized.
-
-
-
-    // Bubble chains. A bubble chain is a linear sequence of bubbles.
-    // Each pair of consecutive bubbles in the sequence may be separated by
-    // a homozygous segment, but the bubble can also be
-    // immediately adjacent (v1 of thr first bubble is the same
-    // as v0 of the second bubble).
-    // For each bubble chain, we store the bubble ids (indexes in
-    // the bubbles vector above).
-    MemoryMapped::VectorOfVectors<uint64_t, uint64_t> bubbleChains;
-    void findBubbleChains(); // Assumes bubbleChains was already initialized.
-
-
     // A table that can be used to find the locations of a marker graph
     // edge in the assembly graph, if any.
     // Note that, before detangling,or if detangling is not used,
@@ -244,52 +213,13 @@ public:
         uint64_t minVertexCount,
         uint64_t minEdgeCount);
 
-
-
-    // Assembly graph forks.
-
-    // A fork is the set of outgoing edges of a vertex with out-degree>1,
-    // or the set of incoming edges of a vertex with in-degree>1.
-    // The edges of the set are called the fork branches.
-    // A fork can have any number of branches>1.
-
-    // A bubble generates only one fork (the set of outgoing edges
-    // of the bubble source vertex which is also the set of
-    // incoming edges of the bubble target vertex).
-    class Fork {
-    public:
-        // The source or target vertex of the fork.
-        VertexId vertexId;
-
-        // Flag which is true if the fork consists of the vertex's
-        // outgoing edges, false if the fork consists of
-        // thevertex's incoming edges.
-        // The fork corresponding to a bubble is stored only once.
-        bool isForward;
-    };
-    MemoryMapped::Vector<Fork> forks;
-    void createForks();
-    span<EdgeId> getForkEdges(uint64_t forkId);
-
-private:
-    // Class used by createForks.
-    class ForkInfo : public Fork {
-    public:
-        vector<EdgeId> edgeIds;
-
-        // Compare using only the edgeIds.
-        bool operator==(const ForkInfo& that) const
-        {
-            return edgeIds == that.edgeIds;
-        }
-        bool operator<(const ForkInfo& that) const
-        {
-            return edgeIds < that.edgeIds;
-        }
-    };
-
-
-
+    // Write the AssemblyGraph to GFA without including sequence.
+    // The sequence length of each edge is written as the number of
+    // marker graph edges.
+    // Equivalent functionbs including output of assembled sequence
+    // are in class Assembler and should be moved here.
+    void writeGfa1BothStrandsNoSequence(const string& fileName) const;
+    void writeGfa1BothStrandsNoSequence(ostream&) const;
 };
 
 
