@@ -4,6 +4,7 @@
 #include "deduplicate.hpp"
 #include "findLinearChains.hpp"
 #include "html.hpp"
+#include "MurmurHash2.hpp"
 #include "platformDependent.hpp"
 #include "Reads.hpp"
 #include "runCommandWithTimeout.hpp"
@@ -13,12 +14,12 @@ using namespace shasta;
 // Boost libraries.
 #include <boost/algorithm/string.hpp>
 #include <boost/graph/iteration_macros.hpp>
-#include <boost/lexical_cast.hpp>
 #include <boost/uuid/uuid.hpp>
 #include <boost/uuid/uuid_generators.hpp>
 #include <boost/uuid/uuid_io.hpp>
 
 // Standard library.
+#include <filesystem>
 #include "fstream.hpp"
 #include "vector.hpp"
 
@@ -955,7 +956,7 @@ void CompressedAssemblyGraph::computeVertexLayout(
             to_string(returnCode) +
             ". The failing command was: " + command);
     }
-    filesystem::remove(dotFileName);
+    std::filesystem::remove(dotFileName);
 
     // Map vertex ids to vertex descriptors.
     std::map<uint64_t, vertex_descriptor> vertexMap;
@@ -994,7 +995,7 @@ void CompressedAssemblyGraph::computeVertexLayout(
             continue;
         }
         // Get the vertex id.
-        const uint64_t vertexId = boost::lexical_cast<uint64_t>(vertexName);
+        const uint64_t vertexId = std::stoul(vertexName);
 
         // Get the corresponding vertex descriptor.
         const auto it = vertexMap.find(vertexId);
@@ -1002,12 +1003,12 @@ void CompressedAssemblyGraph::computeVertexLayout(
 
         // Store it in the layout.
         array<double, 2> x;
-        x[0] = boost::lexical_cast<double>(tokens[2]);
-        x[1] = boost::lexical_cast<double>(tokens[3]);
+        x[0] = std::stod(tokens[2]);
+        x[1] = std::stod(tokens[3]);
         vertexPositions.insert(make_pair(v, x));
     }
     plainFile.close();
-    filesystem::remove(plainFileName);
+    std::filesystem::remove(plainFileName);
 }
 
 
