@@ -2,7 +2,6 @@
 
 // Shasta.
 #include "HttpServer.hpp"
-#include "filesystem.hpp"
 #include "platformDependent.hpp"
 #include "SHASTA_ASSERT.hpp"
 #include "timestamp.hpp"
@@ -10,6 +9,7 @@ using namespace shasta;
 
 // Boost libraries.
 #include <boost/algorithm/string.hpp>
+#include <boost/asio/ip/tcp.hpp>
 #include <boost/asio/io_service.hpp>
 #include <boost/asio/ip/tcp.hpp>
 #include <boost/asio/ip/v6_only.hpp>
@@ -22,6 +22,7 @@ using namespace ip;
 
 // Standard library.
 #include "chrono.hpp"
+#include <filesystem>
 #include "fstream.hpp"
 #include "iostream.hpp"
 #include <regex>
@@ -83,11 +84,7 @@ void HttpServer::explore(uint16_t port, bool localOnly, bool sameUserOnly)
             cout << "Only accepting local connections originating from a process "
                 "owned by the same user running the server." << endl;
             // Also start the default browser and point it to the server.
-#ifdef __linux__
             ::system(("xdg-open http://localhost:" + to_string(port)).c_str());
-#else
-            ::system(("open http://localhost:" + to_string(port)).c_str());
-#endif
         } else {
             cout << "Accepting local connections from any user. "
                 "Connections from the local computer are accepted from any user. "
@@ -104,9 +101,9 @@ void HttpServer::explore(uint16_t port, bool localOnly, bool sameUserOnly)
         cout << "To connect from this computer, "
             "point your browser to http://localhost:" << port << endl;
         cout << "To connect from a different computer, "
-            "point your browser to http://XYZ:" << port << 
+            "point your browser to http://XYZ:" << port <<
             ", where XYZ is either the name or IP address of this computer." << endl;
-        cout << 
+        cout <<
             "All connections are accepted: local and remote, from any user. "
             "This means that all users, not only on the computer running the server, "
             "but also on all computers on the same local area network, can use the server. "
@@ -116,7 +113,7 @@ void HttpServer::explore(uint16_t port, bool localOnly, bool sameUserOnly)
             "TO LOOK AT YOUR DATA AND SHOULD "
             "NOT BE USED IF YOUR ASSEMBLY DATA IS SUBJECT TO "
             "CONFIDENTIALITY RESTRICTIONS OR IS NOT CLEARED OR CONSENTED "
-            "FOR PUBLIC RELEASE." 
+            "FOR PUBLIC RELEASE."
             << endl;
     }
 
@@ -159,7 +156,10 @@ void HttpServer::explore(uint16_t port, bool localOnly, bool sameUserOnly)
 }
 
 
-void HttpServer::setRequestTimeout(int tsec, tcp::iostream& s) {
+// Argument is boost::asio::ip::tcp::iostream&,
+// but make it templated to reduce include file dependencies.
+template<class T> void HttpServer::setRequestTimeout(int tsec, T& s) {
+// void HttpServer::setRequestTimeout(int tsec, tcp::iostream& s) {
 #if BOOST_VERSION < 106600
     s.expires_from_now(boost::posix_time::seconds(tsec));
 #else
@@ -167,7 +167,12 @@ void HttpServer::setRequestTimeout(int tsec, tcp::iostream& s) {
 #endif
 }
 
-void HttpServer::processRequest(tcp::iostream& s)
+
+
+// Argument is boost::asio::ip::tcp::iostream&,
+// but make it templated to reduce include file dependencies.
+template<class T> void HttpServer::processRequest(T& s)
+// void HttpServer::processRequest(tcp::iostream& s)
 {
     // If the client is too slow sending the request, drop it.
     setRequestTimeout(1, s);
@@ -514,7 +519,7 @@ size_t PostData::getContentLength() const
     if(it == headers.end()) {
         throw runtime_error("POST request without content length is not supported.");
     }
-    return lexical_cast<size_t>(it->second);
+    return std::stoul(it->second);
 
 }
 
@@ -654,9 +659,14 @@ void HttpServer::processPostRequest(
 // user running the server.
 // We use the lsof command to find open sockets on 127.0.0.1
 // and the current port as source or destination.
-bool HttpServer::isLocalConnectionSameUser(
-    boost::asio::ip::tcp::iostream& s,
+// Argument is boost::asio::ip::tcp::iostream&,
+// but make it templated to reduce include file dependencies.
+template<class T> bool HttpServer::isLocalConnectionSameUser(
+    T& s,
     uint16_t port) const
+/* bool HttpServer::isLocalConnectionSameUser(
+    boost::asio::ip::tcp::iostream& s,
+    uint16_t port) const */
 {
     // Get out process id.
     const string serverProcessId = to_string(::getpid());
@@ -665,7 +675,7 @@ bool HttpServer::isLocalConnectionSameUser(
     const string uuid = to_string(boost::uuids::random_generator()());
     const string fileName = tmpDirectory() + uuid + ".fa";
     if(::system(("lsof -i -n > " + fileName).c_str())) {
-        filesystem::remove(fileName);
+        std::filesystem::remove(fileName);
         return false;
     }
 
@@ -776,7 +786,7 @@ bool HttpServer::isLocalConnectionSameUser(
             clientProcessUserName = userName;
         }
     }
-    filesystem::remove(fileName);
+    std::filesystem::remove(fileName);
 
     return
         serverProcessUserName.size()>0 &&
