@@ -39,6 +39,10 @@ namespace shasta {
         LocalReadGraphEdge
         >;
 
+    // Triangles of the read graph, each with an alignment residual.
+    class LocalReadGraphTriangles : public vector< pair<array<LocalReadGraphBaseClass::edge_descriptor, 3>, int32_t> >
+        {};
+
     enum class AlignmentType;
 }
 
@@ -61,6 +65,10 @@ public:
     // Used for Blast annotations.
     string additionalToolTipText;
 
+    // The least square position of this vertex,
+    // computed by Assembler::analyzeLocalReadGraph.
+    double leastSquarePosition;
+
     LocalReadGraphVertex(
         OrientedReadId orientedReadId,
         uint32_t markerCount,
@@ -91,11 +99,21 @@ public:
     // Flag that indicates this edge jumps across strands.
     bool crossesStrands;
 
+    // The corresponding global read graph edge.
+    uint64_t globalEdgeId;
+
+    // The average alignment offset.
+    double averageAlignmentOffset = 0.;
+
+    string color;
+
     LocalReadGraphEdge(
         uint32_t markerCount,
-        bool crossesStrands) :
+        bool crossesStrands,
+        uint64_t globalEdgeId) :
         markerCount(markerCount),
-        crossesStrands(crossesStrands)
+        crossesStrands(crossesStrands),
+        globalEdgeId(globalEdgeId)
         {}
 };
 
@@ -115,6 +133,7 @@ public:
         OrientedReadId,
         OrientedReadId,
         uint32_t markerCount,
+        uint64_t globalEdgeId,
         bool crossesStrands);
 
     // Find out if a vertex with a given OrientedReadId exists.
