@@ -2,12 +2,15 @@
 #include "LowHash1.hpp"
 #include "AlignmentCandidates.hpp"
 #include "Marker.hpp"
+#include "MurmurHash2.hpp"
 using namespace shasta;
 
 // Standad library.
 #include "algorithm.hpp"
 #include "chrono.hpp"
 
+#include "MultithreadedObject.tpp"
+template class MultithreadedObject<LowHash1>;
 
 
 LowHash1::LowHash1(
