@@ -3,10 +3,11 @@
 
 // Shasta.
 #include "ReadId.hpp"
-#include"tuple.hpp"
 
 // Standard library.
 #include "array.hpp"
+#include "tuple.hpp"
+#include "vector.hpp"
 
 namespace shasta {
     class MarkerInterval;
@@ -17,7 +18,7 @@ namespace shasta {
 // Class to describe the interval between
 // two markers on an oriented read.
 // The two markers are not necessarily consecutive.
-// HOoever, the second marker has a higher ordinal
+// However, the second marker has a higher ordinal
 // than the first.
 class shasta::MarkerInterval {
 public:
@@ -37,6 +38,13 @@ public:
         ordinals[1] = ordinal1;
     }
 
+    bool operator==(const MarkerInterval& that) const
+    {
+        return
+            tie(orientedReadId, ordinals[0], ordinals[1])
+            ==
+            tie(that.orientedReadId, that.ordinals[0], that.ordinals[1]);
+    }
     bool operator<(const MarkerInterval& that) const
     {
         return
