@@ -4,18 +4,15 @@
 #define SHASTA_MEMORY_MAPPED_VECTOR_HPP
 
 // Shasta.
-#include "SHASTA_ASSERT.hpp"
-#include "filesystem.hpp"
-#include "MurmurHash2.hpp"
+#include "array.hpp"
 #include "touchMemory.hpp"
-
-// Boost libraries.
-#include <boost/lexical_cast.hpp>
+#include "SHASTA_ASSERT.hpp"
 
 // Standard libraries.
 #include <cstring>
 #include "algorithm"
 #include "cstddef.hpp"
+#include <filesystem>
 #include "iostream.hpp"
 #include "stdexcept.hpp"
 #include "string.hpp"
@@ -24,12 +21,10 @@
 // Linux.
 #include <fcntl.h>
 #include <sys/mman.h>
-#ifdef __linux__
 #include <linux/mman.h>
-#endif
 #include <sys/stat.h>
 #include <sys/types.h>
-#include "array.hpp"
+#include <unistd.h>
 
 
 // Forward declarations.
@@ -422,7 +417,7 @@ template<class T> inline int shasta::MemoryMapped::Vector<T>::openExisting(const
         name.c_str(),
         readWriteAccess ? O_RDWR : O_RDONLY);
     if(fileDescriptor == -1) {
-        throw runtime_error("Error " + boost::lexical_cast<string>(errno)
+        throw runtime_error("Error " + to_string(errno)
             + " opening MemoryMapped::Vector " + name + ": " + string(strerror(errno)));
     }
     return fileDescriptor;
@@ -454,7 +449,7 @@ template<class T> inline void* shasta::MemoryMapped::Vector<T>::map(int fileDesc
                 "This assembly requires more memory than available.\n"
                 "Rerun on a larger machine.");
         } else {
-            throw runtime_error("Error " + boost::lexical_cast<string>(errno)
+            throw runtime_error("Error " + to_string(errno)
                 + " during mremap call for MemoryMapped::Vector: " + string(strerror(errno)));
         }
     }
@@ -558,11 +553,9 @@ template<class T> inline void shasta::MemoryMapped::Vector<T>::createNewAnonymou
 
         // Map it in memory.
         int flags = MAP_PRIVATE | MAP_ANONYMOUS;
-#ifdef __linux__
         if(pageSize == 2*1024*1024) {
             flags |= MAP_HUGETLB | MAP_HUGE_2MB;
         }
-#endif
         void* pointer = ::mmap(0, fileSize,
             PROT_READ | PROT_WRITE, flags,
             -1, 0);
@@ -573,7 +566,7 @@ template<class T> inline void shasta::MemoryMapped::Vector<T>::createNewAnonymou
                     "This assembly requires more memory than available.\n"
                     "Rerun on a larger machine.");
             } else {
-                throw runtime_error("Error " + boost::lexical_cast<string>(errno)
+                throw runtime_error("Error " + to_string(errno)
                     + " during mremap call for MemoryMapped::Vector: " + string(strerror(errno)));
             }
         }
@@ -723,7 +716,7 @@ template<class T> inline void shasta::MemoryMapped::Vector<T>::unmapAnonymous()
 
     const int munmapReturnCode = ::munmap(header, header->fileSize);
     if(munmapReturnCode == -1) {
-        throw runtime_error("Error " + boost::lexical_cast<string>(errno)
+        throw runtime_error("Error " + to_string(errno)
             + " unmapping MemoryMapped::Vector: " + string(strerror(errno)));
     }
 
@@ -753,7 +746,7 @@ template<class T> inline void shasta::MemoryMapped::Vector<T>::remove()
     } else {
         const string savedFileName = fileName;
         close();    // This forgets the fileName.
-        filesystem::remove(savedFileName);
+        std::filesystem::remove(savedFileName);
     }
 }
 
@@ -905,11 +898,8 @@ template<class T> inline void
             // We can only use remap for Linux, and for 4K pages.
             bool useMremap = false;
             void* pointer = 0;
-#ifdef __linux__
             useMremap = (pageSize == 4096);
-#endif
             if(useMremap) {
-#ifdef __linux__
                 pointer = ::mremap(header, header->fileSize, headerOnStack.fileSize, MREMAP_MAYMOVE);
                 if(pointer == reinterpret_cast<void*>(-1LL)) {
                     if(errno == ENOMEM) {
@@ -918,21 +908,19 @@ template<class T> inline void
                             "This assembly requires more memory than available.\n"
                             "Rerun on a larger machine.");
                     } else {
-                        throw runtime_error("Error " + boost::lexical_cast<string>(errno)
+                        throw runtime_error("Error " + to_string(errno)
                             + " during mremap call for MemoryMapped::Vector: " + string(strerror(errno)));
                     }
                 }
-#endif
             } else {
 
                 // We cannot use mremap. We have to create a new mapping
                 // and copy the data.
                 int flags = MAP_PRIVATE | MAP_ANONYMOUS;
-#ifdef __linux__
                 if(pageSize == 2*1024*1024) {
                     flags |= MAP_HUGETLB | MAP_HUGE_2MB;
                 }
-#endif
+
                 void* newPointer = ::mmap(0, headerOnStack.fileSize,
                     PROT_READ | PROT_WRITE, flags,
                     -1, 0);
@@ -943,7 +931,7 @@ template<class T> inline void
                             "This assembly requires more memory than available.\n"
                             "Rerun on a larger machine.");
                     } else {
-                        throw runtime_error("Error " + boost::lexical_cast<string>(errno)
+                        throw runtime_error("Error " + to_string(errno)
                             + " during mremap call for MemoryMapped::Vector: " + string(strerror(errno)));
                     }
                 }
@@ -1048,12 +1036,9 @@ template<class T> inline
     // Remap it.
     // We can only use remap for Linux, and for 4K pages.
     bool useMremap = false;
-#ifdef __linux__
     useMremap = (pageSize == 4096);
-#endif
     void* pointer = 0;
     if(useMremap) {
-#ifdef __linux__
         pointer = ::mremap(header, header->fileSize, headerOnStack.fileSize, MREMAP_MAYMOVE);
         if(pointer == reinterpret_cast<void*>(-1LL)) {
             if(errno == ENOMEM) {
@@ -1062,21 +1047,18 @@ template<class T> inline
                     "This assembly requires more memory than available.\n"
                     "Rerun on a larger machine.");
             } else {
-                throw runtime_error("Error " + boost::lexical_cast<string>(errno)
+                throw runtime_error("Error " + to_string(errno)
                     + " during mremap call for MemoryMapped::Vector: " + string(strerror(errno)));
             }
         }
-#endif
     } else {
 
         // We cannot use mremap. We have to create a new mapping
         // and copy the data.
         int flags = MAP_PRIVATE | MAP_ANONYMOUS;
-#ifdef __linux__
         if(pageSize == 2*1024*1024) {
             flags |= MAP_HUGETLB | MAP_HUGE_2MB;
         }
-#endif
         void* newPointer = ::mmap(0, headerOnStack.fileSize,
             PROT_READ | PROT_WRITE, flags,
             -1, 0);
@@ -1087,7 +1069,7 @@ template<class T> inline
                     "This assembly requires more memory than available.\n"
                     "Rerun on a larger machine.");
             } else {
-                throw runtime_error("Error " + boost::lexical_cast<string>(errno)
+                throw runtime_error("Error " + to_string(errno)
                     + " during mremap call for MemoryMapped::Vector: " + string(strerror(errno)));
             }
         }
@@ -1126,23 +1108,11 @@ template<class T> inline void shasta::MemoryMapped::Vector<T>::unreserve()
 // Make a copy of the Vector.
 template<class T> inline void shasta::MemoryMapped::Vector<T>::makeCopy(
     Vector<T>& copy, const string& newName) const
-    {
+{
     copy.createNew(newName, size());
     std::copy(begin(), end(), copy.begin());
 }
 
-// Return a hash function of the stored data.
-// Can be used to check for integrity.
-template<class T> inline uint64_t shasta::MemoryMapped::Vector<T>::hash() const
-{
-    // The second argument to MurmurHash64A is a 4-byte integer.
-    // Sooner or later we will have to deal with this.
-    // For now we just check that there is no overflow.
-    const uint64_t byteCount = size()*sizeof(T);
-    SHASTA_ASSERT(byteCount <= uint64_t(std::numeric_limits<int>::max()));
-    return MurmurHash64A(begin(), int(byteCount), 231);
-}
-
 template<class T> inline void shasta::MemoryMapped::Vector<T>::rename(const string& newFileName)
 {
     SHASTA_ASSERT(isOpen);
@@ -1153,7 +1123,7 @@ template<class T> inline void shasta::MemoryMapped::Vector<T>::rename(const stri
         const string oldFileName = fileName;
         const bool writeAccess = isOpenWithWriteAccess;
         close();
-        filesystem::move(oldFileName, newFileName);
+        std::filesystem::rename(oldFileName, newFileName);
         accessExisting(newFileName, writeAccess);
     }
 }
