@@ -17,6 +17,8 @@ using namespace shasta;
 #include <queue>
 #include "tuple.hpp"
 
+#include "MultithreadedObject.tpp"
+template class MultithreadedObject<PhasingGraph>;
 
 
 void PhasingGraphEdge::runBayesianModel(double epsilon, bool allowRandomHypothesis)
