@@ -1,6 +1,3 @@
-#if 1
-//#ifdef __linux__
-
 #ifndef SHASTA_PNG_IMAGE_HPP
 #define SHASTA_PNG_IMAGE_HPP
 
@@ -22,6 +19,9 @@ public:
     // Construct a magnified version of another PngImage.
     PngImage(const PngImage&, int magnifyFactor);
 
+    // Write a square grid.
+    void writeGrid(int spacing, int red, int green, int blue);
+
     // Magnify this image.
     void magnify(int magnifyFactor);
 
@@ -34,5 +34,4 @@ private:
 };
 
 #endif
-#endif
 
