@@ -8,6 +8,7 @@
 #include "Base.hpp"
 #include "CompactUndirectedGraph.hpp"
 #include "compressAlignment.hpp"
+#include "ConfigurationTable.hpp"
 #include "deduplicate.hpp"
 #include "dset64Test.hpp"
 #include "diploidBayesianPhase.hpp"
@@ -21,8 +22,9 @@
 #include "Reads.hpp"
 #include "ShortBaseSequence.hpp"
 #include "splitRange.hpp"
-#include "testSpoa.hpp"
 #include "SimpleBayesianConsensusCaller.hpp"
+#include "testSpoa.hpp"
+#include "testSubsetGraph.hpp"
 using namespace shasta;
 
 // Pybind11
@@ -659,6 +661,10 @@ PYBIND11_MODULE(shasta, shastaModule)
             &Assembler::accessMode3AssemblyGraph)
         .def("analyzeMode3Subgraph",
             &Assembler::analyzeMode3Subgraph)
+        .def("createMode3PathGraph",
+            &Assembler::createMode3PathGraph)
+        .def("createMode3Detangler",
+            &Assembler::createMode3Detangler)
 
 
 
@@ -706,6 +712,7 @@ PYBIND11_MODULE(shasta, shastaModule)
     shastaModule.attr("invalidGlobalMarkerGraphVertexId") = MarkerGraph::invalidVertexId;
     shastaModule.attr("invalidCompressedGlobalMarkerGraphVertexId") =
         uint64_t(MarkerGraph::invalidCompressedVertexId);
+    shastaModule.attr("configurationTable") = shasta::configurationTable;
 
 
 
@@ -760,6 +767,9 @@ PYBIND11_MODULE(shasta, shastaModule)
     shastaModule.def("mappedCopy",
         mappedCopy
         );
+    shastaModule.def("testLongBaseSequence",
+        testLongBaseSequence
+        );
     shastaModule.def("testAlignmentCompression",
         testAlignmentCompression
         );
@@ -772,6 +782,9 @@ PYBIND11_MODULE(shasta, shastaModule)
     shastaModule.def("testDiploidBayesianPhase",
         testDiploidBayesianPhase
         );
+    shastaModule.def("testSubsetGraph",
+        testSubsetGraph
+        );
 }
 
 #endif
