@@ -14,7 +14,12 @@ namespace shasta {
     // Find linear chains of edges (paths).
     template<class Graph> void findLinearChains(
         const Graph&,
+        uint64_t minimumLength,
         vector< std::list<typename Graph::edge_descriptor> >&);
+    template<class Graph> void findLinearChains(
+        const Graph&,
+        uint64_t minimumLength,
+        vector< vector<typename Graph::edge_descriptor> >&);
 
 
     // Find linear chains of vertices.
@@ -28,9 +33,31 @@ namespace shasta {
 
 
 
+// Version that uses vectors.
+template<class Graph> void shasta::findLinearChains(
+    const Graph& graph,
+    uint64_t minimumLength,
+    vector< vector<typename Graph::edge_descriptor> >& chainVectors)
+{
+    using edge_descriptor = typename Graph::edge_descriptor;
+
+    // Call the version that uses lists.
+    vector< std::list<edge_descriptor> > chains;
+    findLinearChains(graph, minimumLength, chains);
+
+    // Copy the lists to vectors.
+    chainVectors.clear();
+    for(const auto& chain: chains) {
+        chainVectors.push_back(vector<edge_descriptor>(chain.begin(), chain.end()));
+    }
+}
+
+
+
 // Find linear chains of edges (paths).
 template<class Graph> inline void shasta::findLinearChains(
     const Graph& graph,
+    uint64_t minimumLength,
     vector< std::list<typename Graph::edge_descriptor> >& chains)
 {
     using vertex_descriptor = typename Graph::vertex_descriptor;
@@ -106,10 +133,21 @@ template<class Graph> inline void shasta::findLinearChains(
             }
         }
 
+        // If the chain is too short, get rid of it.
+        if(chain.size() < minimumLength) {
+            chains.resize(chains.size() - 1);
+        }
+
     }
 
     // Check that all edges were found.
-    SHASTA_ASSERT(edgesFound.size() == num_edges(graph));
+    // Just using num_edges does not work if the graph is a filtered_graph.
+    // SHASTA_ASSERT(edgesFound.size() == num_edges(graph));
+    uint64_t edgeCount = 0;
+    BGL_FORALL_EDGES_T(e, graph, Graph) {
+        ++edgeCount;
+    }
+    SHASTA_ASSERT(edgesFound.size() == edgeCount);
 }
 
 
