@@ -5,7 +5,6 @@
 
 namespace shasta {
     using std::cin;
-    using std::cerr;
     using std::cout;
     using std::dec;
     using std::endl;
@@ -13,6 +12,9 @@ namespace shasta {
     using std::hex;
     using std::istream;
     using std::ostream;
+
+    // In Shasta we don't use cerr. All log output is to cout.
+    // using std::cerr;
 }
 
 #endif
