@@ -1,9 +1,7 @@
-#ifdef SHASTA_HTTP_SERVER
-
-
-
 // Shasta.
 #include "mode3-LocalAssemblyGraph.hpp"
+#include "mode3-AssemblyPath.hpp"
+#include "mode3-SegmentPairInformation.hpp"
 #include "computeLayout.hpp"
 #include "html.hpp"
 #include "HttpServer.hpp"
@@ -154,7 +152,8 @@ void mode3::LocalAssemblyGraph::writeHtml(ostream& html, const SvgOptions& optio
 {
     // Write the svg object.
     html << "<div style='display: inline-block; vertical-align:top'>";
-    writeSvg(html, options);
+    vector<mode3::AssemblyGraph::AnalyzeSubgraphClasses::Cluster> clusters;
+    writeSvg(html, options, clusters);
     html << "</div>";
     addSvgDragAndZoom(html);
 
@@ -196,6 +195,12 @@ void mode3::LocalAssemblyGraph::writeHtml(ostream& html, const SvgOptions& optio
             segmentId = inputField.value;
             inputField.value = "";
 
+            zoomToGivenSegment(segmentId);
+        }
+
+        function zoomToGivenSegment(segmentId)
+        {
+
             // Find the bounding box and its center.
             var element = document.getElementById("Segment-" + segmentId);
             var box = element.getBBox();
@@ -222,6 +227,22 @@ void mode3::LocalAssemblyGraph::writeHtml(ostream& html, const SvgOptions& optio
 
 
 
+    // Initial zoom to segment of interest.
+    if(options.segmentColoring == "path") {
+        html << "\n<script>zoomToGivenSegment(" << options.pathStart << ");</script>\n";
+    }
+    if(
+        options.segmentColoring == "byCommonReads" or
+        options.segmentColoring == "byJaccard" or
+        options.segmentColoring == "byRawJaccard" or
+        options.segmentColoring == "byUnexplainedFractionOnReferenceSegment" or
+        options.segmentColoring == "byUnexplainedFractionOnDisplayedSegment"
+        ) {
+        html << "\n<script>zoomToGivenSegment(" << options.referenceSegmentId << ");</script>\n";
+    }
+
+
+
     // Tables that will be automatically updated when the mouse is on a segment.
     html << R"zzz(  
 <p>
@@ -259,6 +280,16 @@ Comparison of read compositions
 <th id='shortReferenceCell'>
 <th id='shortDisplayedCell'>
 
+<tr>
+<th class='left'>Jaccard
+<th id='jaccardReferenceCell'>
+<th id='jaccardDisplayedCell'>
+
+<tr>
+<th class='left'>Raw Jaccard
+<th id='rawJaccardReferenceCell'>
+<th id='rawJaccardDisplayedCell'>
+
 <tr>
 <th class='left'>Unexplained
 <th id='unexplainedReferenceCell'>
@@ -294,12 +325,18 @@ function onMouseEnterSegment(id, distance, pathLength, coverage, clusterId,
     if(common > 0) {
         document.getElementById('shortReferenceCell').innerHTML = shortReference;
         document.getElementById('shortDisplayedCell').innerHTML = shortDisplayed;
+        jaccard = (common / (common + unexplainedReference + unexplainedDisplayed)).toFixed(2);
+        rawJaccard = (common / (totalReference + totalDisplayed - common)).toFixed(2);
+        document.getElementById('jaccardReferenceCell').innerHTML = jaccard;
+        document.getElementById('jaccardDisplayedCell').innerHTML = jaccard;
+        document.getElementById('rawJaccardReferenceCell').innerHTML = rawJaccard;
+        document.getElementById('rawJaccardDisplayedCell').innerHTML = rawJaccard;
         document.getElementById('unexplainedReferenceCell').innerHTML = unexplainedReference;
         document.getElementById('unexplainedDisplayedCell').innerHTML = unexplainedDisplayed;
         document.getElementById('unexplainedFractionReferenceCell').innerHTML = 
-            (unexplainedReference / totalReference).toFixed(2);
+            (unexplainedReference / (common + unexplainedReference)).toFixed(2);
         document.getElementById('unexplainedFractionDisplayedCell').innerHTML = 
-            (unexplainedDisplayed / totalDisplayed).toFixed(2);
+            (unexplainedDisplayed / (common + unexplainedDisplayed)).toFixed(2);
     }   
 }
 function onMouseExitSegment()
@@ -316,6 +353,8 @@ function onMouseExitSegment()
     document.getElementById('shortDisplayedCell').innerHTML = '';
     document.getElementById('commonReferenceCell').innerHTML = '';
     document.getElementById('commonDisplayedCell').innerHTML = '';
+    document.getElementById('jaccardReferenceCell').innerHTML = '';
+    document.getElementById('jaccardDisplayedCell').innerHTML = '';
     document.getElementById('unexplainedReferenceCell').innerHTML = '';
     document.getElementById('unexplainedDisplayedCell').innerHTML = '';
     document.getElementById('unexplainedFractionReferenceCell').innerHTML = '';
@@ -330,19 +369,20 @@ function onMouseExitSegment()
     html << R"stringDelimiter(
     <p><table>
     <tr><th class=left>Segment thickness<td>
-    <button type='button' onClick='segmentThickness(0.5)' style='width:2em'>--</button>
-    <button type='button' onClick='segmentThickness(0.8)' style='width:2em'>-</button>
-    <button type='button' onClick='segmentThickness(1.25)' style='width:2em'>+</button>
-    <button type='button' onClick='segmentThickness(2)' style='width:2em'>++</button>
+    <button type='button' onClick='segmentThickness(0.1)' style='width:3em'>---</button>
+    <button type='button' onClick='segmentThickness(0.5)' style='width:3em'>--</button>
+    <button type='button' onClick='segmentThickness(0.8)' style='width:3em'>-</button>
+    <button type='button' onClick='segmentThickness(1.25)' style='width:3em'>+</button>
+    <button type='button' onClick='segmentThickness(2.)' style='width:3em'>++</button>
+    <button type='button' onClick='segmentThickness(10.)' style='width:3em'>+++</button>
         <script>
         function segmentThickness(factor)
         {
             const group = document.getElementById('LocalAssemblyGraph-segments');
-            for (let i=0; i<group.children.length; i++) {
-                path = group.children[i];
-                if(path.tagName == 'path') {
-                    path.setAttribute('stroke-width', factor * path.getAttribute('stroke-width'));
-                }
+            descendants = group.querySelectorAll("path");
+            for (let i=0; i<descendants.length; i++) {
+                path = descendants[i];
+                path.setAttribute('stroke-width', factor * path.getAttribute('stroke-width'));
             }
         }
         </script>
@@ -353,10 +393,12 @@ function onMouseExitSegment()
     // Change link thickness
     html << R"stringDelimiter(
     <tr><th class=left>Link thickness<td>
-    <button type='button' onClick='linkThickness(0.5)' style='width:2em'>--</button>
-    <button type='button' onClick='linkThickness(0.8)' style='width:2em'>-</button>
-    <button type='button' onClick='linkThickness(1.25)' style='width:2em'>+</button>
-    <button type='button' onClick='linkThickness(2.)' style='width:2em'>++</button>
+    <button type='button' onClick='linkThickness(0.1)' style='width:3em'>---</button>
+    <button type='button' onClick='linkThickness(0.5)' style='width:3em'>--</button>
+    <button type='button' onClick='linkThickness(0.8)' style='width:3em'>-</button>
+    <button type='button' onClick='linkThickness(1.25)' style='width:3em'>+</button>
+    <button type='button' onClick='linkThickness(2.)' style='width:3em'>++</button>
+    <button type='button' onClick='linkThickness(10.)' style='width:3em'>+++</button>
         <script>
         function linkThickness(factor)
         {
@@ -374,10 +416,92 @@ function onMouseExitSegment()
             }
         }
         </script>
+        )stringDelimiter";
+
+
+
+    // Zoom buttons.
+    html << R"stringDelimiter(
+    <tr title='Or use the mouse wheel.'><th class=left>Zoom<td>
+    <button type='button' onClick='zoomSvg(0.1)' style='width:3em'>---</button>
+    <button type='button' onClick='zoomSvg(0.5)' style='width:3em'>--</button>
+    <button type='button' onClick='zoomSvg(0.8)' style='width:3em'>-</button>
+    <button type='button' onClick='zoomSvg(1.25)' style='width:3em'>+</button>
+    <button type='button' onClick='zoomSvg(2.)' style='width:3em'>++</button>
+    <button type='button' onClick='zoomSvg(10.)' style='width:3em'>+++</button>
      </table>
         )stringDelimiter";
 
 
+    // Code to display one local cluster at a time, with a button
+    // to cycle through them.
+    if(options.segmentColoring == "byLocalCluster") {
+        html <<
+            "<br>Found " << clusters.size() << " clusters. "
+            "Displaying cluster <span id='currentCluster'></span>"
+            "<br><button onClick='previousCluster()'>Previous<br>cluster</button>"
+            "<button onClick='nextCluster()'>Next<br>cluster</button>"
+            "<script>\n"
+            "var clusters = [";
+        for(uint64_t i=0; i<clusters.size(); i++) {
+            html << "[";
+            const auto & cluster = clusters[i];
+            for(uint64_t j=0; j<cluster.segments.size(); j++) {
+                html << cluster.segments[j].first;
+                if(j != cluster.segments.size() - 1) {
+                    html << ",";
+                }
+            }
+            html << "]";
+            if(i != clusters.size() -1) {
+                html << ",";
+            }
+        }
+        html << "];\n";
+
+        html << R"stringDelimiter(
+
+        function clusterColor(clusterId)
+        {
+            var ratio = clusterId / clusters.length;
+            return 'hsl(' + Math.round(360*ratio) + ', 85%, 70%)';
+        }
+
+        function highlightCluster(clusterId, color)
+        {
+            for(i=0; i<clusters[clusterId].length; i++) {
+                segmentId = clusters[clusterId][i];
+                document.getElementById("Segment-" + segmentId).style.stroke = color;
+                document.getElementById("marker" + segmentId).style.fill = color;
+            }
+        }
+        var currentCluster = 0;
+        highlightCluster(currentCluster, clusterColor(currentCluster));
+        document.getElementById("currentCluster").innerHTML = currentCluster;
+        function nextCluster()
+        {
+            highlightCluster(currentCluster, "Black");
+            currentCluster = currentCluster + 1;
+            if(currentCluster == clusters.length) {
+                currentCluster = 0;
+            }
+            highlightCluster(currentCluster, clusterColor(currentCluster));
+            document.getElementById("currentCluster").innerHTML = currentCluster;
+        }
+        function previousCluster()
+        {
+            highlightCluster(currentCluster, "Black");
+            if(currentCluster == 0) {
+                currentCluster = clusters.length;
+            }
+            currentCluster = currentCluster - 1;
+            highlightCluster(currentCluster, clusterColor(currentCluster));
+            document.getElementById("currentCluster").innerHTML = currentCluster;
+        }
+        </script>
+
+        )stringDelimiter";
+    }
 
     // End of side panel.
     html << "</div>";
@@ -388,14 +512,17 @@ function onMouseExitSegment()
 
 void mode3::LocalAssemblyGraph::writeSvg(
     const string& fileName,
-    const SvgOptions& options) const
+    const SvgOptions& options,
+    vector<mode3::AssemblyGraph::AnalyzeSubgraphClasses::Cluster>& clusters) const
 {
     ofstream svg(fileName);
-    writeSvg(svg, options);
+    writeSvg(svg, options, clusters);
 }
 void mode3::LocalAssemblyGraph::writeSvg(
     ostream& svg,
-    const SvgOptions& options) const
+    const SvgOptions& options,
+    vector<mode3::AssemblyGraph::AnalyzeSubgraphClasses::Cluster>& clusters
+    ) const
 {
     const LocalAssemblyGraph& localAssemblyGraph = *this;
 
@@ -404,7 +531,7 @@ void mode3::LocalAssemblyGraph::writeSvg(
     // containing pair information between the reference segment
     // and each segment in the local assembly graph.
     const bool doSegmentPairComputations = true;
-    std::map<vertex_descriptor, mode3::AssemblyGraph::SegmentPairInformation> segmentPairInformationTable;
+    std::map<vertex_descriptor, SegmentPairInformation> segmentPairInformationTable;
     mode3::AssemblyGraph::SegmentOrientedReadInformation referenceSegmentInfo;
     if(doSegmentPairComputations) {
 
@@ -417,7 +544,7 @@ void mode3::LocalAssemblyGraph::writeSvg(
             assemblyGraph.getOrientedReadsOnSegment(
                 localAssemblyGraph[v].segmentId, segmentInfo);
 
-            mode3::AssemblyGraph::SegmentPairInformation segmentPairInformation;
+            SegmentPairInformation segmentPairInformation;
             assemblyGraph.analyzeSegmentPair(
                 options.referenceSegmentId, localAssemblyGraph[v].segmentId,
                 referenceSegmentInfo, segmentInfo,
@@ -428,6 +555,66 @@ void mode3::LocalAssemblyGraph::writeSvg(
     }
 
 
+    std::map<uint64_t, vector<pair<uint64_t, bool> > > pathSegments; // map(segmentId, (positionsInPath, is referenceSegment)).
+    AssemblyPath path;
+    if(options.segmentColoring == "path") {
+        if(options.pathDirection=="forward" or options.pathDirection=="backward") {
+            // Forward or backward.
+            assemblyGraph.createAssemblyPath(options.pathStart,
+                (options.pathDirection == "forward") ? 0 : 1, path);
+            if(options.pathDirection == "backward") {
+                reverse(path.segments.begin(), path.segments.end());
+            }
+        } else {
+            // Bidirectional.
+            AssemblyPath forwardPath;
+            AssemblyPath backwardPath;
+            assemblyGraph.createAssemblyPath(options.pathStart, 0, forwardPath);
+            assemblyGraph.createAssemblyPath(options.pathStart, 1, backwardPath);
+            // Stitch them together, making sure not to repeat the starting segment.
+            path.segments.clear();
+            copy(backwardPath.segments.rbegin(), backwardPath.segments.rend(), back_inserter(path.segments));
+            copy(forwardPath.segments.begin() + 1, forwardPath.segments.end(), back_inserter(path.segments));
+        }
+        for(uint64_t position=0; position<path.segments.size(); position++) {
+            const AssemblyPathSegment& segment = path.segments[position];
+            const uint64_t segmentId = segment.id;
+            pathSegments[segmentId].push_back(make_pair(position, segment.isPrimary));
+        }
+        svg << "\nPath of length " << path.segments.size() << " starting at segment " << path.segments.front().id <<
+            " and ending at segment " << path.segments.back().id << "<br>";
+
+        ofstream csv("Path.csv");
+        csv << "Position,SegmentId,Reference\n";
+        for(uint64_t position=0; position<path.segments.size(); position++) {
+            const AssemblyPathSegment& segment = path.segments[position];
+            csv << position << "," << segment.id << "," << int(segment.isPrimary) << "\n";
+        }
+
+        // If requested, assemble path sequence.
+        if(options.assemblePathSequence) {
+            path.assemble(assemblyGraph);
+        }
+    }
+
+
+
+    // If coloring by local cluster, call mode3::AssemblyGraph::analyzeSubgraph,
+    // passing as input all the segments in the LocalAssemblyGraph
+    // except those at maximum distance.
+    if(options.segmentColoring == "byLocalCluster") {
+        vector<uint64_t> segmentIds;
+        BGL_FORALL_VERTICES(v, localAssemblyGraph, LocalAssemblyGraph) {
+            const LocalAssemblyGraphVertex& vertex = localAssemblyGraph[v];
+            if(vertex.distance != maxDistance) {
+                segmentIds.push_back(vertex.segmentId);
+            }
+        }
+        assemblyGraph.analyzeSubgraph(segmentIds, clusters, true);
+
+    }
+
+
 
     // If coloring by cluster id only some clusters, create a color map
     // for the clusters to be colored.
@@ -497,6 +684,7 @@ void mode3::LocalAssemblyGraph::writeSvg(
     svg << "<g id='" << svgId << "-links'>\n";
     BGL_FORALL_EDGES(e, localAssemblyGraph, LocalAssemblyGraph) {
         const uint64_t linkId = localAssemblyGraph[e].linkId;
+        const AssemblyGraph::Link& link = assemblyGraph.links[linkId];
 
         // Access the LocalAssemblyGraph vertices corresponding to
         // the two segments of this Link and extract some information
@@ -507,7 +695,6 @@ void mode3::LocalAssemblyGraph::writeSvg(
         const LocalAssemblyGraphVertex& vertex2 = localAssemblyGraph[v2];
         const uint64_t segmentId1 = vertex1.segmentId;
         const uint64_t segmentId2 = vertex2.segmentId;
-        const bool areConsecutivePaths = haveConsecutivePaths(v1, v2);
 
         // Get the positions of the ends of this link.
         SHASTA_ASSERT(vertex1.position.size() >= 2);
@@ -532,9 +719,35 @@ void mode3::LocalAssemblyGraph::writeSvg(
             options.additionalLinkThicknessPerRead * double(assemblyGraph.linkCoverage(linkId) - 1);
 
         const string dash =
-            areConsecutivePaths ? "" :
+            link.segmentsAreAdjacent ? "" :
             " stroke-dasharray='0 " + to_string(1.5 * linkThickness) + "'";
 
+        // If the link participates in a path, color it consistently with the
+        // segments is joins.
+        string linkColor = options.linkColor;
+        if(options.segmentColoring == "path") {
+            const auto it1 = pathSegments.find(segmentId1);
+            if(it1 != pathSegments.end()) {
+                const auto positions1 = it1->second;
+                SHASTA_ASSERT(not positions1.empty());
+                const auto it2 = pathSegments.find(segmentId2);
+                if(it2 != pathSegments.end()) {
+                    const auto positions2 = it2->second;
+                    SHASTA_ASSERT(not positions2.empty());
+                    if(positions1.size()==1 and positions2.size()==1) {
+                        const uint64_t position1 = positions1.front().first;
+                        const uint64_t position2 = positions2.front().first;
+                        if(position2 == position1 + 1) {
+                            const uint32_t hue = uint32_t(
+                                std::round(120. * double(position1 + position2) / double(path.segments.size())));
+                            linkColor = "hsl(" + to_string(hue) + ",100%, 20%)";
+                        }
+                    } else {
+                        linkColor = "Fuchsia";
+                    }
+                }
+            }
+        }
 
         svg <<
             "<g>"
@@ -544,13 +757,14 @@ void mode3::LocalAssemblyGraph::writeSvg(
             " from segment " << segmentId1 <<
             " to segment " << segmentId2 <<
             ", coverage " << assemblyGraph.linkCoverage(linkId) <<
+            ", separation " << link.separation <<
             "</title>"
             "<path d="
             "'M " << p1.x() << " " << p1.y() <<
             " C " << q1.x() << " " << q1.y() << ", "
                   << q2.x() << " " << q2.y() << ","
                   << p2.x() << " " << p2.y() << "'"
-            " stroke='" << options.linkColor << "'" <<
+            " stroke='" << linkColor << "'" <<
             dash <<
             " stroke-width='" << linkThickness << "'"
             " stroke-linecap='round'"
@@ -612,6 +826,24 @@ void mode3::LocalAssemblyGraph::writeSvg(
                 }
                 const uint64_t hue = uint64_t(std::round(fraction * 120.));
                 color = "hsl(" + to_string(hue) + ",100%, 50%)";
+            } else if(options.segmentColoring == "byJaccard") {
+                const auto& pairInfo = segmentPairInformationTable[v];
+                if(pairInfo.commonCount > 0) {
+                    const double jaccard = pairInfo.jaccard();
+                    const uint64_t hue = uint64_t(std::round(jaccard * 120.));
+                    color = "hsl(" + to_string(hue) + ",100%, 50%)";
+                } else {
+                    color = "blue";
+                }
+            } else if(options.segmentColoring == "byRawJaccard") {
+                const auto& pairInfo = segmentPairInformationTable[v];
+                if(pairInfo.commonCount > 0) {
+                    const double rawJaccard = pairInfo.rawJaccard();
+                    const uint64_t hue = uint64_t(std::round(rawJaccard * 120.));
+                    color = "hsl(" + to_string(hue) + ",100%, 50%)";
+                } else {
+                    color = "blue";
+                }
             } else if(options.segmentColoring == "byUnexplainedFractionOnReferenceSegment") {
                 const auto& pairInfo = segmentPairInformationTable[v];
                 if(pairInfo.commonCount > 0) {
@@ -650,6 +882,25 @@ void mode3::LocalAssemblyGraph::writeSvg(
                         }
                     }
                 }
+            } else if(options.segmentColoring == "path") {
+                auto it = pathSegments.find(segmentId);
+                if(it == pathSegments.end()) {
+                    color = "Black";
+                } else {
+                    const auto positions = it->second;
+                    SHASTA_ASSERT(not positions.empty());
+                    if(positions.size() == 1) {
+                        const auto& p = positions.front();
+                        const uint64_t positionInPath = p.first;
+                        const bool isReferenceSegment = p.second;
+                        const uint32_t hue = uint32_t(
+                            std::round(240. * double(positionInPath) / double(path.segments.size())));
+                        color = "hsl(" + to_string(hue) + ",100%, " + (isReferenceSegment ? "40%" : "70%") + ")";
+                    } else {
+                        // This segment appears more than once on the path.
+                        color = "Fuchsia";
+                    }
+                }
             } else {
                 color = "Black";
             }
@@ -671,7 +922,7 @@ void mode3::LocalAssemblyGraph::writeSvg(
             "markerUnits='strokeWidth'\n"
             "markerWidth='0.6' markerHeight='1'\n"
             "orient='auto'>\n"
-            "<path d='M 0 0 L 0.1 0 L 0.6 0.5 L 0.1 1 L 0 1 z' "
+            "<path id='marker" << segmentId << "' d='M 0 0 L 0.1 0 L 0.6 0.5 L 0.1 1 L 0 1 z' "
             "fill='" << color << "' "
             "/>\n"
             "</marker>\n"
@@ -681,6 +932,21 @@ void mode3::LocalAssemblyGraph::writeSvg(
         const auto& segmentPairInfo = segmentPairInformationTable[v];
         const auto oldPrecision = svg.precision(1);
         const auto oldFlags = svg.setf(std::ios_base::fixed, std::ios_base::floatfield);
+
+        if(options.segmentColoring == "path") {
+            svg << "<g>";
+            auto it = pathSegments.find(segmentId);
+            if(it != pathSegments.end()) {
+                const auto positions = it->second;
+                SHASTA_ASSERT(not positions.empty());
+                svg << "<title>";
+                for(const auto& p: positions) {
+                    svg << p.first << " ";
+                }
+                svg << "</title>";
+            }
+        }
+
         /*
         svg <<
             "<g>"
@@ -702,7 +968,7 @@ void mode3::LocalAssemblyGraph::writeSvg(
             " onmouseenter='onMouseEnterSegment(" <<
             segmentId << "," <<
             distance << "," <<
-            assemblyGraph.paths.size(segmentId) << "," <<
+            assemblyGraph.markerGraphPaths.size(segmentId) << "," <<
             averageEdgeCoverage << "," <<
             assemblyGraph.clusterIds[segmentId] << "," <<
             segmentPairInfo.totalCount[0] << "," <<
@@ -734,13 +1000,18 @@ void mode3::LocalAssemblyGraph::writeSvg(
             " marker-end='url(#" <<
             arrowMarkerName <<
             ")'"
-            " onclick='if(event.ctrlKey) {location.href=\"exploreMode3AssemblyGraphSegment?segmentId=" << segmentId << "\";}'"
+            " onclick='if(event.ctrlKey) {"
+            "location.href=\"exploreMode3AssemblyGraphSegment?segmentId=" << segmentId <<
+            "&showSequence=on\";}'"
             "/>"
             // "</a>"
             // "</g>"
             "\n";
         svg.precision(oldPrecision);
         svg.flags(oldFlags);
+        if(options.segmentColoring == "path") {
+            svg << "</g>";
+        }
     }
     svg << "</g>\n";
 
@@ -767,7 +1038,7 @@ void mode3::LocalAssemblyGraph::computeLayout(
     BGL_FORALL_VERTICES(v, localAssemblyGraph, LocalAssemblyGraph) {
         const uint64_t segmentId = localAssemblyGraph[v].segmentId;
 
-        const uint64_t pathLength = assemblyGraph.paths.size(segmentId);
+        const uint64_t pathLength = assemblyGraph.markerGraphPaths.size(segmentId);
         const double displayLength =
             options.minimumSegmentLength +
             double(pathLength - 1) * options.additionalSegmentLengthPerMarker;
@@ -791,13 +1062,16 @@ void mode3::LocalAssemblyGraph::computeLayout(
     BGL_FORALL_EDGES(e, localAssemblyGraph, LocalAssemblyGraph) {
         const vertex_descriptor v1 = source(e, localAssemblyGraph);
         const vertex_descriptor v2 = target(e, localAssemblyGraph);
+        const LocalAssemblyGraphEdge& edge = localAssemblyGraph[e];
+        const uint64_t linkId = edge.linkId;
+        const AssemblyGraph::Link& link = assemblyGraph.links[linkId];
 
         double edgeLength;
-        if(haveConsecutivePaths(v1, v2)) {
+        if(link.segmentsAreAdjacent) {
             edgeLength = options.minimumLinkLength;
         } else {
-            const double linkSeparation = max(this->linkSeparation(e), 0.);
-            edgeLength = 3. * options.minimumLinkLength + linkSeparation * options.additionalLinkLengthPerMarker;
+            const int32_t linkSeparation = max(link.separation, 0);
+            edgeLength = 3. * options.minimumLinkLength + double(linkSeparation) * options.additionalLinkLengthPerMarker;
         }
         G::edge_descriptor eAuxiliary;
         tie(eAuxiliary, ignore) = add_edge(
@@ -981,8 +1255,8 @@ bool LocalAssemblyGraph::haveConsecutivePaths(
     const uint64_t segmentId0 = vertex0.segmentId;
     const uint64_t segmentId1 = vertex1.segmentId;
 
-    const auto path0 = assemblyGraph.paths[segmentId0];
-    const auto path1 = assemblyGraph.paths[segmentId1];
+    const auto path0 = assemblyGraph.markerGraphPaths[segmentId0];
+    const auto path1 = assemblyGraph.markerGraphPaths[segmentId1];
 
     const MarkerGraphEdgeId edgeId0 = path0.back();
     const MarkerGraphEdgeId edgeId1 = path1.front();
@@ -997,21 +1271,11 @@ bool LocalAssemblyGraph::haveConsecutivePaths(
 
 // Return the average link separation for the Link
 // described by an edge.
-double LocalAssemblyGraph::linkSeparation(edge_descriptor e) const
+int32_t LocalAssemblyGraph::linkSeparation(edge_descriptor e) const
 {
     const LocalAssemblyGraph& localAssemblyGraph = *this;
-
-    // Get the path length of the first segment.
-    const vertex_descriptor v0 = source(e, localAssemblyGraph);
-    const LocalAssemblyGraphVertex& vertex0 = localAssemblyGraph[v0];
-    const uint64_t segmentId0 = vertex0.segmentId;
-    const auto path0 = assemblyGraph.paths[segmentId0];
-    const uint64_t pathLength0 = path0.size();
-
-    // Now we can compute the link separation.
     const uint64_t linkId = localAssemblyGraph[e].linkId;
-    return mode3::AssemblyGraph::linkSeparation(assemblyGraph.transitions[linkId], pathLength0);
-
+    return assemblyGraph.links[linkId].separation;
 }
 
 
@@ -1019,6 +1283,20 @@ double LocalAssemblyGraph::linkSeparation(edge_descriptor e) const
 // Construct the svg options from an html request.
 LocalAssemblyGraph::SvgOptions::SvgOptions(const vector<string>& request)
 {
+    // The initial layout method if set to "custom" if
+    // command "customLayout" is available, "neato" otherwise.
+    static bool firstTime = true;
+    static string layoutDefaultMethod = "neato";
+    if(firstTime) {
+        firstTime = false;
+        const string command = "which customLayout";
+        const int returnCode = system(command.c_str());
+        if(returnCode == 0) {
+            layoutDefaultMethod = "custom";
+        }
+    }
+    layoutMethod = layoutDefaultMethod;
+
     HttpServer::getParameterValue(request, "sizePixels", sizePixels);
     HttpServer::getParameterValue(request, "layoutMethod", layoutMethod);
 
@@ -1034,13 +1312,15 @@ LocalAssemblyGraph::SvgOptions::SvgOptions(const vector<string>& request)
     HttpServer::getParameterValue(request, "greenThreshold", greenThreshold);
     HttpServer::getParameterValue(request, "referenceSegmentId", referenceSegmentId);
     HttpServer::getParameterValue(request, "hashSeed", hashSeed);
+    HttpServer::getParameterValue(request, "pathStart", pathStart);
+    HttpServer::getParameterValue(request, "pathDirection", pathDirection);
 
     string clustersToBeColoredString;
     HttpServer::getParameterValue(request, "clustersToBeColored", clustersToBeColoredString);
     clustersToBeColored.clear();
     if(not clustersToBeColoredString.empty()) {
         vector<string> tokens;
-        boost::algorithm::split(tokens, clustersToBeColoredString, boost::algorithm::is_any_of(" "));
+        boost::algorithm::split(tokens, clustersToBeColoredString, boost::algorithm::is_any_of(","));
         for(const string& token: tokens) {
             try {
                 const uint64_t clusterId =std::stoi(token);
@@ -1051,6 +1331,10 @@ LocalAssemblyGraph::SvgOptions::SvgOptions(const vector<string>& request)
         }
     }
 
+    // Flag to turn on sequence assembly when coloring a path.
+    string assemblePathSequenceString;
+    assemblePathSequence = HttpServer::getParameterValue(request, "assemblePathSequence", assemblePathSequenceString);
+
     // Link length and thickness.
     HttpServer::getParameterValue(request, "minimumLinkLength", minimumLinkLength);
     HttpServer::getParameterValue(request, "additionalLinkLengthPerMarker", additionalLinkLengthPerMarker);
@@ -1123,6 +1407,18 @@ void LocalAssemblyGraph::SvgOptions::addFormRows(ostream& html)
                 " value='" << segmentColor << "'>"
         "<hr>"
 
+        // Segment coloring by Jaccard similarity with the reference segment.
+        "<input type=radio name=segmentColoring value=byJaccard"
+        << (segmentColoring=="byJaccard" ? " checked=checked" : "") <<
+        ">By Jaccard similarity with reference segment, without counting short reads"
+        "<br>"
+
+        // Segment coloring by raw Jaccard similarity with the reference segment.
+        "<input type=radio name=segmentColoring value=byRawJaccard"
+        << (segmentColoring=="byRawJaccard" ? " checked=checked" : "") <<
+        ">By raw Jaccard similarity with reference segment (no special treatment of short reads)"
+        "<br>"
+
         // Segment coloring by number of common reads with the reference segment.
         "<input type=radio name=segmentColoring value=byCommonReads"
         << (segmentColoring=="byCommonReads" ? " checked=checked" : "") <<
@@ -1158,13 +1454,40 @@ void LocalAssemblyGraph::SvgOptions::addFormRows(ostream& html)
                 " value='" << hashSeed << "'><br>"
         "Only color clusters&nbsp;<input type=text name=clustersToBeColored size=8 style='text-align:center'"
                 " value='";
-         for(const uint64_t clusterId: clustersToBeColored) {
-             html << clusterId << " ";
-         }
-         html <<  "'><br>"
+     for(const uint64_t clusterId: clustersToBeColored) {
+         html << clusterId << ",";
+     }
+     html <<  "'><hr>"
+
+         // Segment coloring by local cluster
+         // (computed by analyzeSubgraph using as input only the segments at
+         // distance less than maxDistance).
+         "<input type=radio name=segmentColoring value=byLocalCluster"
+         << (segmentColoring=="byLocalCluster" ? " checked=checked" : "") <<
+         ">By local cluster"
+         "<br>";
+
+         // Segment coloring using a path.
+         html <<
+             "<hr>"
+             "<input type=radio name=segmentColoring value=path"
+             << (segmentColoring=="path" ? " checked=checked" : "") <<
+             ">Color an assembly path"
+             "<br>"
+             "Start the path at segment &nbsp;<input type=text name=pathStart size=8 style='text-align:center'"
+                     " value='" << pathStart << "'>"
+             "<br><input type=radio name=pathDirection value=forward" <<
+             (pathDirection=="forward" ? " checked=checked" : "") << "> Forward"
+             "<br><input type=radio name=pathDirection value=backward" <<
+             (pathDirection=="backward" ? " checked=checked" : "") << "> Backward"
+             "<br><input type=radio name=pathDirection value=bidirectional" <<
+             (pathDirection=="bidirectional" ? " checked=checked" : "") << "> Both directions" <<
+             "<br><input type=checkbox name=assemblePathSequence" <<
+             (assemblePathSequence ? " checked=checked" : "") <<
+             "> Assemble path sequence.";
 
 
-        "</table>"
+        html << "</table>"
 
 
 
@@ -1201,6 +1524,22 @@ void LocalAssemblyGraph::SvgOptions::addFormRows(ostream& html)
 
 
 
+// Return true if there were no changes in the options
+// that affect graph layout changed, compared to another
+// SvgOptions object.
+bool LocalAssemblyGraph::SvgOptions::hasSameLayoutOptions(const SvgOptions& that) const
+{
+    return
+        (layoutMethod == that.layoutMethod) and
+        (minimumSegmentLength == that.minimumSegmentLength) and
+        (additionalSegmentLengthPerMarker == that.additionalSegmentLengthPerMarker) and
+        (minimumLinkLength == that.minimumLinkLength) and
+        (additionalLinkLengthPerMarker == that.additionalLinkLengthPerMarker)
+        ;
+}
+
+
+
 // Write the local assembly graph in gfa format.
 void LocalAssemblyGraph::writeGfa(const string& fileName) const
 {
@@ -1217,7 +1556,7 @@ void LocalAssemblyGraph::writeGfa(ostream& gfa) const
     // Write the segments.
     BGL_FORALL_VERTICES(v, localAssemblyGraph, LocalAssemblyGraph) {
         const uint64_t segmentId = localAssemblyGraph[v].segmentId;
-        const auto path = assemblyGraph.paths[segmentId];
+        const auto path = assemblyGraph.markerGraphPaths[segmentId];
         gfa <<
             "S\t" << segmentId << "\t" <<
             "*\tLN:i:" << path.size() << "\n";
@@ -1235,6 +1574,3 @@ void LocalAssemblyGraph::writeGfa(ostream& gfa) const
 
 }
 
-
-
-#endif
