@@ -1,6 +1,6 @@
 // Main program for the Shasta static executable.
 // The static executable provides
-// basic functionality and reduced performance. 
+// basic functionality and reduced performance.
 // For full functionality use the shared library built
 // under directory src.
 
@@ -63,10 +63,7 @@ namespace shasta {
         void listCommands();
         void listConfigurations();
         void listConfiguration(const AssemblerOptions&);
-
-#ifdef SHASTA_HTTP_SERVER
         void explore(const AssemblerOptions&);
-#endif
 
         const std::set<string> commands = {
             "assemble",
@@ -137,7 +134,7 @@ void shasta::main::segmentFaultHandler(int)
 {
     char message[] = "\nA segment fault occurred. Please report it by filing an "
         "issue on the Shasta repository and attaching the entire log output. "
-        "To file an issue, point your browser to https://github.com/chanzuckerberg/shasta/issues\n";
+        "To file an issue, point your browser to https://github.com/paoloshasta/shasta/issues\n";
     ::write(fileno(stderr), message, sizeof(message));
     ::_exit(1);
 }
@@ -175,11 +172,7 @@ void shasta::main::main(int argumentCount, const char** arguments)
         saveBinaryData(assemblerOptions);
         return;
     } else if(assemblerOptions.commandLineOnlyOptions.command == "explore") {
-#ifdef SHASTA_HTTP_SERVER
         explore(assemblerOptions);
-#else
-        throw runtime_error("This Shasta build does not include HTTP server support.");
-#endif
         return;
     } else if(assemblerOptions.commandLineOnlyOptions.command == "createBashCompletionScript") {
         createBashCompletionScript(assemblerOptions);
@@ -242,6 +235,18 @@ void shasta::main::assemble(
             " specified for --MinHash.version. Must be 0 or 1.");
     }
 
+    // Check assemblerOptions.minHashOptions minimum/maximum bucket size.
+    if( assemblerOptions.minHashOptions.maxBucketSize <=
+        assemblerOptions.minHashOptions.minBucketSize) {
+        throw runtime_error("MinHash maximum bucket size must be greater than minimum bucket size. "
+            "The following values were specified:"
+            " minimum bucket size " +
+            to_string(assemblerOptions.minHashOptions.minBucketSize) +
+            ", maximum bucket size " +
+            to_string(assemblerOptions.minHashOptions.maxBucketSize) + "."
+            );
+    }
+
     // If coverage data was requested, memoryMode should be filesystem,
     // otherwise the coverage data cannot be accessed.
     if(assemblerOptions.assemblyOptions.storeCoverageData) {
@@ -254,7 +259,7 @@ void shasta::main::assemble(
     if( assemblerOptions.alignOptions.alignMethod <  0 or
         assemblerOptions.alignOptions.alignMethod == 2 or
         assemblerOptions.alignOptions.alignMethod >  4) {
-        throw runtime_error("Align method " + to_string(assemblerOptions.alignOptions.alignMethod) + 
+        throw runtime_error("Align method " + to_string(assemblerOptions.alignOptions.alignMethod) +
             " is not valid. Valid options are 0, 1, 3, and 4.");
     }
 
@@ -315,11 +320,11 @@ void shasta::main::assemble(
                 "Empty it for reuse or use --assemblyDirectory to specify a different assembly directory.");
         }
     } else {
-        filesystem::createDirectory(assemblerOptions.commandLineOnlyOptions.assemblyDirectory);
+        SHASTA_ASSERT(std::filesystem::create_directory(assemblerOptions.commandLineOnlyOptions.assemblyDirectory));
     }
 
     // Make the assembly directory current.
-    filesystem::changeDirectory(assemblerOptions.commandLineOnlyOptions.assemblyDirectory);
+    std::filesystem::current_path(assemblerOptions.commandLineOnlyOptions.assemblyDirectory);
 
     // Open the performance log.
     openPerformanceLog("performance.log");
@@ -361,7 +366,6 @@ void shasta::main::assemble(
 
 
     // Initial disclaimer message.
-#ifdef __linux
     if(assemblerOptions.commandLineOnlyOptions.memoryBacking != "2M" &&
         assemblerOptions.commandLineOnlyOptions.memoryMode != "filesystem") {
         cout << "This run uses options \"--memoryBacking " << assemblerOptions.commandLineOnlyOptions.memoryBacking <<
@@ -372,12 +376,6 @@ void shasta::main::assemble(
             "Therefore the results of this run should not be used\n"
             "for benchmarking purposes." << endl;
     }
-#else
-    cout << "The macOS version of the Shasta assembler runs at degraded performance.\n";
-    cout << "Use Linux for full performance.\n";
-    cout << "Therefore the results of this run should not be used\n"
-        "for benchmarking purposes." << endl;
-#endif
 
     // Create the Assembler.
     Assembler assembler(dataDirectory, true, assemblerOptions.readsOptions.representation, pageSize);
@@ -389,7 +387,6 @@ void shasta::main::assemble(
     assemble(assembler, assemblerOptions, inputFileAbsolutePaths);
 
     // Final disclaimer message.
-#ifdef __linux
     if(assemblerOptions.commandLineOnlyOptions.memoryBacking != "2M" &&
         assemblerOptions.commandLineOnlyOptions.memoryMode != "filesystem") {
         cout << "This run used options \"--memoryBacking " << assemblerOptions.commandLineOnlyOptions.memoryBacking <<
@@ -400,12 +397,6 @@ void shasta::main::assemble(
             "Therefore the results of this run should not be used\n"
             "for benchmarking purposes." << endl;
     }
-#else
-    cout << "The macOS version of the Shasta assembler runs at degraded performance.\n";
-    cout << "Use Linux for full performance.\n";
-    cout << "Therefore the results of this run should not be used\n"
-        "for benchmarking purposes." << endl;
-#endif
 
     // Write out the build id again.
     cout << buildId() << endl;
@@ -462,7 +453,7 @@ void shasta::main::setupRunDirectory(
 
             // Binary files on disk.
             // This does not require root privilege.
-            filesystem::createDirectory("Data");
+            SHASTA_ASSERT(std::filesystem::create_directory("Data"));
             dataDirectory = "Data/";
             pageSize = 4096;
 
@@ -472,7 +463,7 @@ void shasta::main::setupRunDirectory(
             // (filesystem in memory backed by 4K pages).
             // This requires root privilege, which is obtained using sudo
             // and may result in a password prompting depending on sudo set up.
-            filesystem::createDirectory("Data");
+            SHASTA_ASSERT(std::filesystem::create_directory("Data"));
             dataDirectory = "Data/";
             pageSize = 4096;
             const string command = "sudo mount -t tmpfs -o size=0 tmpfs Data";
@@ -489,7 +480,7 @@ void shasta::main::setupRunDirectory(
             // This requires root privilege, which is obtained using sudo
             // and may result in a password prompting depending on sudo set up.
             setupHugePages();
-            filesystem::createDirectory("Data");
+            SHASTA_ASSERT(std::filesystem::create_directory("Data"));
             dataDirectory = "Data/";
             pageSize = 2 * 1024 * 1024;
             const uid_t userId = ::getuid();
@@ -560,7 +551,7 @@ void shasta::main::assemble(
     if(assembler.getReads().readCount() == 0) {
         throw runtime_error("There are no input reads.");
     }
-    
+
 
 
     // If requested, increase the read length cutoff
@@ -583,13 +574,13 @@ void shasta::main::assemble(
                 ", less than desired coverage " +
                 to_string(assemblerOptions.readsOptions.desiredCoverage) +
                 ". Try reducing Reads.minReadLength if appropriate or get more coverage."
-            ); 
+            );
         }
 
         // Adjusting coverage should only ever reduce coverage if necessary.
         SHASTA_ASSERT(newMinReadLength >= oldMinReadLength);
     }
-    
+
     assembler.computeReadIdsSortedByName();
     assembler.histogramReadLength("ReadLengthHistogram.csv");
 
@@ -819,9 +810,14 @@ void shasta::main::assemble(
     assembler.storeAssemblyTime(elapsedTime, averageCpuUtilization);
 
     // Store peak memory usage.
-    uint64_t peakMemoryUsage = shasta::getPeakMemoryUsage();
+    uint64_t peakMemoryUsage = getPeakMemoryUsage();
     assembler.storePeakMemoryUsage(peakMemoryUsage);
 
+    // Store other performance information.
+    assembler.assemblerInfo->threadCount = threadCount;
+    assembler.assemblerInfo->virtualCpuCount = std::thread::hardware_concurrency();
+    assembler.assemblerInfo->totalAvailableMemory = getTotalPhysicalMemory();
+
     // Write a summary of read information.
     assembler.writeReadsSummary();
 
@@ -1281,14 +1277,13 @@ void shasta::main::cleanupBinaryData(
     const string dataOnDiskDirectory =
         assemblerOptions.commandLineOnlyOptions.assemblyDirectory + "/DataOnDisk";
     if(std::filesystem::exists(dataOnDiskDirectory)) {
-        filesystem::changeDirectory(assemblerOptions.commandLineOnlyOptions.assemblyDirectory);
+        std::filesystem::current_path(assemblerOptions.commandLineOnlyOptions.assemblyDirectory);
         const string command = "ln -s DataOnDisk Data";
         ::system(command.c_str());
     }
 
 }
 
-#ifdef SHASTA_HTTP_SERVER
 // Implementation of --command explore.
 void shasta::main::explore(
     const AssemblerOptions& assemblerOptions)
@@ -1307,12 +1302,12 @@ void shasta::main::explore(
     }
 
     // Go to the assembly directory.
-    filesystem::changeDirectory(assemblerOptions.commandLineOnlyOptions.assemblyDirectory);
-    
-    // Check that we have the binary data. 
+    std::filesystem::current_path(assemblerOptions.commandLineOnlyOptions.assemblyDirectory);
+
+    // Check that we have the binary data.
     if(!std::filesystem::exists("Data")) {
         throw runtime_error("Binary directory \"Data\" not available "
-        " in assembly directory " + 
+        " in assembly directory " +
         assemblerOptions.commandLineOnlyOptions.assemblyDirectory +
         ". Use \"--memoryMode filesystem\", possibly followed by "
         "\"--command saveBinaryData\" and \"--command cleanupBinaryData\" "
@@ -1321,18 +1316,18 @@ void shasta::main::explore(
         );
         return;
     }
-    
+
     // Create the Assembler.
     Assembler assembler("Data/", false, 1, 0);
-    
-    // Access all available binary data.
-    assembler.accessAllSoft();
-    
+
     // Set up the consensus caller.
     cout << "Setting up consensus caller " <<
         assemblerOptions.assemblyOptions.consensusCaller << endl;
     assembler.setupConsensusCaller(assemblerOptions.assemblyOptions.consensusCaller);
 
+    // Access all available binary data.
+    assembler.accessAllSoft();
+
     string executablePath = filesystem::executablePath();
     // On Linux it will be something like - `/path/to/install_root/bin/shasta`
 
@@ -1371,16 +1366,15 @@ void shasta::main::explore(
         );
     }
     assembler.explore(
-        assemblerOptions.commandLineOnlyOptions.port, 
-        localOnly, 
+        assemblerOptions.commandLineOnlyOptions.port,
+        localOnly,
         sameUserOnly);
 }
 
-#endif
 
 
 // This creates a bash completion script for the Shasta executable,
-// which makes it esaier to type long option names.
+// which makes it easier to type long option names.
 // To use it:
 // shasta --command createBashCompletionScript; source shastaCompletion.sh
 // Then, press TAB once or twice while editing a Shasta command line
@@ -1392,7 +1386,7 @@ void shasta::main::explore(
 // AND THE ABILITY TO COMPLETE KEYWORDS ONLY AFTER THE OPTION THEY
 // SHOULD BE PRECEDED BY.
 // IF SOMEBODY WITH A GOOD UNDERSTANDING OF BASH COMPLETION SEES THIS,
-// PLESE MAKE IT BETTER AND SUBMIT A PULL REQUEST!
+// PLEASE MAKE IT BETTER AND SUBMIT A PULL REQUEST!
 void shasta::main::createBashCompletionScript(const AssemblerOptions& assemblerOptions)
 {
     const string fileName = "shastaCompletion.sh";
